@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -602,6 +602,40 @@ acm_dialog_about (AcmObject *acm_object,
 }
 
 
+/*  ja:設定ダイアログのサポートを確認する
+    acm_object,AcmObject
+           RET,TRUE:有効,FALSE:無効                                         */
+gboolean
+acm_is_dialog_preference (AcmObject *acm_object)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  return acm_object && acm_object->hDrvr
+            && SendDriverMessage (acm_object->hDrvr, DRV_QUERYCONFIGURE, 0, 0);
+#else /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+  return FALSE;
+#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
+/*  ja:設定ダイアログを表示する
+    acm_object,AcmObject
+        widget,親ウインドウ                                                 */
+void
+acm_dialog_preference (AcmObject *acm_object,
+                       GtkWidget *widget)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  if (acm_object && acm_object->hDrvr)
+    SendDriverMessage (acm_object->hDrvr, DRV_CONFIGURE,
+# if defined (G_OS_WIN32)
+        widget ? GPOINTER_TO_INT (GDK_WINDOW_HWND (widget->window)) : 0, 0);
+# elif defined (USE_W32LDR)
+                                                GPOINTER_TO_INT (widget), 0);
+# endif /* defined (USE_W32LDR) */
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
 /******************************************************************************
 *                                                                             *
 * en:ACM Convert                                                              *
