@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -575,6 +575,40 @@ icm_dialog_configure (IcmObject *icm_object,
 }
 
 
+/*  ja:ドライバ設定ダイアログのサポートを確認する
+    icm_object,IcmObject
+           RET,TRUE:有効,FALSE:無効                                         */
+gboolean
+icm_is_dialog_preference (IcmObject *icm_object)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  return icm_object && icm_object->hDrvr
+            && SendDriverMessage (icm_object->hDrvr, DRV_QUERYCONFIGURE, 0, 0);
+#else /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+  return FALSE;
+#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
+/*  ja:ドライバ設定ダイアログを表示する
+    icm_object,IcmObject
+        widget,親ウインドウ                                                 */
+void
+icm_dialog_preference (IcmObject *icm_object,
+                       GtkWidget *widget)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  if (icm_object && icm_object->hDrvr)
+    SendDriverMessage (icm_object->hDrvr, DRV_CONFIGURE,
+# if defined (G_OS_WIN32)
+        widget ? GPOINTER_TO_INT (GDK_WINDOW_HWND (widget->window)) : 0, 0);
+# elif defined (USE_W32LDR)
+                                                GPOINTER_TO_INT (widget), 0);
+# endif /* defined (USE_W32LDR) */
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ICMパラメータ                                                            *
