@@ -1,6 +1,6 @@
 /*
     fileio
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define __FILEIO_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
 #endif /* HAVE_FCNTL_H */
@@ -73,8 +73,8 @@ extern "C" {
 # define FILEIO_SEEK_END            SEEK_END
 #endif /* not G_OS_WIN32 */
 #define FILEIO_SHARE_DENY           0
-#define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ | FILEIO_ACCESS_WRITE)
-#define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ | FILEIO_SHARE_WRITE)
+#define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ|FILEIO_ACCESS_WRITE)
+#define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ|FILEIO_SHARE_WRITE)
 
 
 typedef struct _FileIO FileIO;
@@ -163,6 +163,13 @@ fileio_unref (FileIO *fio);
 #define fileio_close(fio) fileio_unref(fio)
 
 
+/*  ja:ファイルの名前を取得する
+    fio,ファイルポインタ
+    RET,名前(フルパス)                                                      */
+const gchar *
+fileio_getname (FileIO *fio);
+
+
 /*  ja:ファイルから読み込む
        fio,ファイルポインタ
       data,バッファ
@@ -203,6 +210,13 @@ goffset
 fileio_size (FileIO *fio);
 
 
+/*  ja:ファイルの終端を設定する
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+gboolean
+fileio_eof (FileIO *fio);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:高レベルファイル入出力関数群                                             *
@@ -277,6 +291,13 @@ gboolean
 fileio_mkdir (const gchar *dir);
 
 
+/*  ja:ファイル/ディレクトリを削除する
+    path,ファイル/ディレクトリ名
+     RET,TRUE:正常終了,FALSE,エラー                                         */
+gboolean
+fileio_remove (const gchar *path);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ファイル時刻関数群                                                       *
@@ -304,14 +325,22 @@ fileio_settime (const gchar *file,
                 FileIOTime  *mtime);
 
 
-/*  ja:ファイルの時刻を変換する
+/*  ja:システム時刻を取得する
     ftime,ファイルの時刻
-    stime,システム時刻                                                      */
+    stime,システム時間                                                      */
 void
 fileio_getsystime (FileIOTime    *ftime,
                    FileIOSysTime *stime);
 
 
+/*  ja:システム時刻を設定する
+    ftime,ファイルの時刻
+    stime,システム時間                                                      */
+void
+fileio_setsystime (FileIOTime    *ftime,
+                   FileIOSysTime *stime);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:応用ファイル関数群                                                       *
