@@ -17,6 +17,7 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "change.h"
+#include "codec.h"
 #include "command.h"
 #include "file.h"
 #include "general.h"
@@ -942,6 +943,14 @@ command_pref (GtkWidget *widget,
 }
 
 
+void
+command_codec (GtkWidget *widget,
+               gpointer   user_data)
+{
+  codec_dialog ();
+}
+
+
 void
 command_version (GtkWidget *widget,
                  gpointer   user_data)
