@@ -121,7 +121,7 @@ file_open_window (VmaidWindow *vmaid,
   gtk_widget_add_events (vmaid->drawing, GDK_POINTER_MOTION_MASK
                             | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
                             | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
-                            | GDK_FOCUS_CHANGE_MASK);
+                            | GDK_FOCUS_CHANGE_MASK | GDK_SCROLL_MASK);
   gtk_widget_set_size_request (vmaid->drawing,
                     vmaid->width + (vmaid->selfrm ? vmaid->width * 2 + 4 : 2),
                         system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
