@@ -315,7 +315,7 @@ merge_dialog (void)
 
 #if GTK_CHECK_VERSION(2,8,0)
       pixbuf = fileio_extract_icon (orz_mdi_get_file (ORZ_MDI (mdi), i),
-                                    FILEIO_ICON_SIZE_SMALL);
+                                    GTK_ICON_SIZE_MENU);
 #endif /* GTK_CHECK_VERSION(2,8,0) */
       gtk_list_store_append (store, &iter);
       gtk_list_store_set (store, &iter, 
