@@ -52,9 +52,9 @@
 #define CF_SELECTSCRIPT         0x00400000
 #define CF_NOSCRIPTSEL          0x00800000
 #define CF_NOVERTFONTS          0x01000000
-#define SIMULATED_FONTTYPE      0x8000
-#define PRINTER_FONTTYPE        0x4000
-#define SCREEN_FONTTYPE         0x2000
+#define SIMULATED_FONTTYPE 0x8000
+#define PRINTER_FONTTYPE   0x4000
+#define SCREEN_FONTTYPE    0x2000
 typedef UINT (CALLBACK *LPCFHOOKPROC)(HWND, UINT, WPARAM, LPARAM);
 #include "pshpack1.h"
 typedef struct _CHOOSEFONTA
@@ -187,6 +187,11 @@ typedef struct _OPENFILENAMEW
 #endif /* W32LDR_HEADER */
 
 
+#ifndef PANGO_VERSION_CHECK
+# define PANGO_VERSION_CHECK(major,minor,micro) 0
+#endif /* not PANGO_VERSION_CHECK */
+
+
 /* ChooseColorA ordinal = 101, argument = 4 temporary */
 static DWORD WINAPI ChooseColorA (DWORD dwArgv0)
 {
@@ -201,17 +206,284 @@ static DWORD WINAPI ChooseColorW (DWORD dwArgv0)
 }
 
 
-/* ChooseFontA ordinal = 103, argument = 4 temporary */
-static DWORD WINAPI ChooseFontA (DWORD dwArgv0)
+/* ChooseFontA ordinal = 103, argument = 4 */
+BOOL WINAPI ChooseFontA (LPCHOOSEFONTA lpcf)
 {
-  return 0;
+  CHOOSEFONTW cf;
+  LOGFONTW lf;
+
+  if (!lpcf || !lpcf->lpLogFont)
+    return FALSE;
+  if (lpcf->Flags & CF_INITTOLOGFONTSTRUCT)
+    {
+      gchar *utf8str;
+
+      lf.lfHeight = lpcf->lpLogFont->lfHeight;
+      lf.lfWidth = lpcf->lpLogFont->lfWidth;
+      lf.lfEscapement = lpcf->lpLogFont->lfEscapement;
+      lf.lfOrientation = lpcf->lpLogFont->lfOrientation;
+      lf.lfWeight = lpcf->lpLogFont->lfWeight;
+      lf.lfItalic = lpcf->lpLogFont->lfItalic;
+      lf.lfUnderline = lpcf->lpLogFont->lfUnderline;
+      lf.lfStrikeOut = lpcf->lpLogFont->lfStrikeOut;
+      lf.lfCharSet = lpcf->lpLogFont->lfCharSet;
+      lf.lfOutPrecision = lpcf->lpLogFont->lfOutPrecision;
+      lf.lfClipPrecision = lpcf->lpLogFont->lfClipPrecision;
+      lf.lfQuality = lpcf->lpLogFont->lfQuality;
+      lf.lfPitchAndFamily = lpcf->lpLogFont->lfPitchAndFamily;
+      lf.lfFaceName[0] = '\0';
+      utf8str = w32ldr_utf8_from_mb (lpcf->lpLogFont->lfFaceName);
+      if (utf8str)
+        {
+          gunichar2 *wc;
+
+          wc = g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL);
+          g_free (utf8str);
+          if (wc)
+            {
+              lstrcpynW (lf.lfFaceName, wc, LF_FACESIZE);
+              g_free (wc);
+            }
+        }
+    }
+  cf.lStructSize = sizeof (CHOOSEFONTW);
+  cf.hwndOwner = lpcf->hwndOwner;
+  cf.hDC = NULL;
+  cf.lpLogFont = &lf;
+  cf.Flags = lpcf->Flags;
+  cf.rgbColors = lpcf->rgbColors;
+  cf.lCustData = 0;
+  cf.lpfnHook = NULL;
+  cf.lpTemplateName = NULL;
+  cf.hInstance = NULL;
+  cf.lpszStyle = NULL;
+  cf.___MISSING_ALIGNMENT__ = 0;
+  cf.nSizeMin = 0;
+  cf.nSizeMax = 0;
+  if (ChooseFontW (&cf))
+    {
+      gchar *utf8str;
+
+      lpcf->iPointSize = cf.iPointSize;
+      lpcf->rgbColors = cf.rgbColors;
+      lpcf->nFontType = cf.nFontType;
+      lpcf->lpLogFont->lfHeight = lf.lfHeight;
+      lpcf->lpLogFont->lfWidth = lf.lfWidth;
+      lpcf->lpLogFont->lfEscapement = lf.lfEscapement;
+      lpcf->lpLogFont->lfOrientation = lf.lfOrientation;
+      lpcf->lpLogFont->lfWeight = lf.lfWeight;
+      lpcf->lpLogFont->lfItalic = lf.lfItalic;
+      lpcf->lpLogFont->lfUnderline = lf.lfUnderline;
+      lpcf->lpLogFont->lfStrikeOut = lf.lfStrikeOut;
+      lpcf->lpLogFont->lfCharSet = lf.lfCharSet;
+      lpcf->lpLogFont->lfOutPrecision = lf.lfOutPrecision;
+      lpcf->lpLogFont->lfClipPrecision = lf.lfClipPrecision;
+      lpcf->lpLogFont->lfQuality = lf.lfQuality;
+      lpcf->lpLogFont->lfPitchAndFamily = lf.lfPitchAndFamily;
+      lpcf->lpLogFont->lfFaceName[0] = '\0';
+      utf8str = g_utf16_to_utf8 (lf.lfFaceName, -1, NULL, NULL, NULL);
+      if (utf8str)
+        {
+          gchar *mb;
+
+          mb = w32ldr_utf8_to_mb (utf8str);
+          g_free (utf8str);
+          if (mb)
+            {
+              g_strncpy (lpcf->lpLogFont->lfFaceName, mb, LF_FACESIZE);
+              g_free (mb);
+            }
+        }
+      return TRUE;
+    }
+  return FALSE;
 }
 
 
-/* ChooseFontW ordinal = 104, argument = 4 temporary */
-static DWORD WINAPI ChooseFontW (DWORD dwArgv0)
+#if ! GTK_CHECK_VERSION(2,4,0)
+static void
+commdlg_clicked (GtkWidget *widget,
+                 GdkColor  *color)
 {
-  return 0;
+  GtkWidget *dialog;
+
+  dialog = gtk_color_selection_dialog_new ("Color");
+  gtk_color_selection_set_current_color (GTK_COLOR_SELECTION
+                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION
+                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
+  gtk_widget_destroy (dialog);
+}
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+
+
+/* ChooseFontW ordinal = 104, argument = 4 */
+BOOL WINAPI ChooseFontW (LPCHOOSEFONTW lpcf)
+{
+  GdkColor color;
+  GtkWidget *dialog, *parent, *button, *check_strike, *check_under;
+  BOOL fResult = FALSE;
+
+  if (!lpcf || !lpcf->lpLogFont || lpcf->lStructSize < sizeof (CHOOSEFONTW))
+    return FALSE;
+  color.pixel = 0;
+  color.red = GetRValue (lpcf->rgbColors) * 256;
+  color.green = GetGValue (lpcf->rgbColors) * 256;
+  color.blue = GetBValue (lpcf->rgbColors) * 256;
+  dialog = gtk_font_selection_dialog_new ("Font");
+
+  for (parent = lpcf->hwndOwner; parent;
+                                    parent = gtk_widget_get_parent (parent))
+    if (GTK_IS_WINDOW (parent))
+      {
+        gtk_window_set_transient_for (GTK_WINDOW (dialog),
+                                                        GTK_WINDOW (parent));
+        break;
+      }
+  if (lpcf->Flags & CF_EFFECTS)
+    {
+      GtkWidget *hbox;
+
+      check_strike = gtk_check_button_new_with_mnemonic ("_Strike Out");
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_strike),
+                                                lpcf->lpLogFont->lfStrikeOut);
+      check_under = gtk_check_button_new_with_mnemonic ("_Under Line");
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_under),
+                                                lpcf->lpLogFont->lfUnderline);
+#if GTK_CHECK_VERSION(2,4,0)
+      button = gtk_color_button_new_with_color (&color);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+      button = gtk_button_new_with_mnemonic ("_Color");
+      g_signal_connect (G_OBJECT (button), "clicked",
+                                        G_CALLBACK (commdlg_clicked), &color);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+      hbox = gtk_hbox_new (FALSE, SPACING);
+      gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), check_strike, FALSE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (hbox), check_under, FALSE, FALSE, 0);
+      gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+                                                        hbox, FALSE, FALSE, 0);
+      gtk_widget_show_all (hbox);
+    }
+  else
+    {
+      button = check_strike = check_under = NULL;
+    }
+  if (lpcf->Flags & CF_INITTOLOGFONTSTRUCT)
+    {
+      gchar *name;
+      PangoFontDescription *desc;
+
+      desc = pango_font_description_new ();
+      name = g_utf16_to_utf8 (lpcf->lpLogFont->lfFaceName, -1,
+                                                            NULL, NULL, NULL);
+      if (name)
+        {
+          pango_font_description_set_family (desc, name);
+          g_free (name);
+        }
+      pango_font_description_set_style (desc, lpcf->lpLogFont->lfItalic
+                                    ? PANGO_STYLE_NORMAL : PANGO_STYLE_ITALIC);
+      pango_font_description_set_variant (desc, PANGO_VARIANT_NORMAL);
+      pango_font_description_set_weight (desc,
+                                    (PangoWeight)lpcf->lpLogFont->lfWeight);
+      pango_font_description_set_stretch (desc, PANGO_STRETCH_NORMAL);
+#if PANGO_VERSION_CHECK(1,8,0)
+      if (lpcf->lpLogFont->lfHeight >= 0)
+        pango_font_description_set_size (desc,
+                                    lpcf->lpLogFont->lfHeight * PANGO_SCALE);
+      else
+        pango_font_description_set_absolute_size (desc,
+                                    -lpcf->lpLogFont->lfHeight * PANGO_SCALE);
+#else /* not PANGO_VERSION_CHECK(1,8,0) */
+      pango_font_description_set_size (desc,
+                                ABS (lpcf->lpLogFont->lfHeight) * PANGO_SCALE);
+#endif /* not PANGO_VERSION_CHECK(1,8,0) */
+#if PANGO_VERSION_CHECK(1,16,0)
+      pango_font_description_set_gravity (desc, PANGO_GRAVITY_AUTO);
+#endif /* PANGO_VERSION_CHECK(1,16,0) */
+      name = pango_font_description_to_string (desc);
+      pango_font_description_free (desc);
+      if (name)
+        {
+          gtk_font_selection_set_font_name (GTK_FONT_SELECTION (dialog), name);
+          g_free (name);
+        }
+    }
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      gchar *name;
+      PangoFontDescription *desc;
+
+      if (lpcf->Flags & CF_EFFECTS)
+        {
+          lpcf->lpLogFont->lfStrikeOut = gtk_toggle_button_get_active
+                                            (GTK_TOGGLE_BUTTON (check_strike));
+          lpcf->lpLogFont->lfUnderline = gtk_toggle_button_get_active
+                                            (GTK_TOGGLE_BUTTON (check_under));
+#if GTK_CHECK_VERSION(2,4,0)
+          if (button)
+            gtk_color_button_get_color (GTK_COLOR_BUTTON (button), &color);
+#endif /* GTK_CHECK_VERSION(2,4,0) */
+          lpcf->rgbColors = RGB (color.red / 256,
+                                 color.green / 256,
+                                 color.blue / 256);
+        }
+      else
+        {
+          lpcf->lpLogFont->lfStrikeOut = lpcf->lpLogFont->lfUnderline = FALSE;
+        }
+      lpcf->nFontType = SIMULATED_FONTTYPE;
+      name = gtk_font_selection_get_font_name (GTK_FONT_SELECTION (dialog));
+      desc = name ? pango_font_description_from_string (name) : NULL;
+      g_free (name);
+      lpcf->lpLogFont->lfWidth = 0;
+      lpcf->lpLogFont->lfEscapement = 0;
+      lpcf->lpLogFont->lfOrientation = 0;
+      lpcf->lpLogFont->lfCharSet = ANSI_CHARSET;
+      lpcf->lpLogFont->lfOutPrecision = OUT_DEFAULT_PRECIS;
+      lpcf->lpLogFont->lfClipPrecision = CLIP_DEFAULT_PRECIS;
+      lpcf->lpLogFont->lfQuality = DEFAULT_QUALITY;
+      lpcf->lpLogFont->lfPitchAndFamily = DEFAULT_PITCH | FF_DONTCARE;
+      lpcf->lpLogFont->lfFaceName[0] = '\0';
+      if (desc)
+        {
+          const gchar *family;
+          gunichar2 *wc;
+
+#if PANGO_VERSION_CHECK(1,8,0)
+          lpcf->lpLogFont->lfHeight = pango_font_description_get_size (desc)
+                * (pango_font_description_get_size_is_absolute (desc) ? -1 : 1)
+                                                                / PANGO_SCALE;
+#else /* not PANGO_VERSION_CHECK(1,8,0) */
+          lpcf->lpLogFont->lfHeight
+                        = pango_font_description_get_size (desc) / PANGO_SCALE;
+#endif /* not PANGO_VERSION_CHECK(1,8,0) */
+          lpcf->lpLogFont->lfWeight
+                            = (LONG)pango_font_description_get_weight (desc);
+          lpcf->lpLogFont->lfItalic = pango_font_description_get_style
+                                                (desc) != PANGO_STYLE_NORMAL;
+          family = pango_font_description_get_family (desc);
+          wc = family ? g_utf8_to_utf16 (family, -1, NULL, NULL, NULL) : NULL;
+          if (wc)
+            {
+              lstrcpynW (lpcf->lpLogFont->lfFaceName, wc, LF_FACESIZE);
+              g_free (wc);
+            }
+          pango_font_description_free (desc);
+        }
+      else
+        {
+          lpcf->lpLogFont->lfHeight = 0;
+          lpcf->lpLogFont->lfWeight = (LONG)PANGO_WEIGHT_NORMAL;
+          lpcf->lpLogFont->lfItalic = FALSE;
+        }
+      lpcf->iPointSize = ABS (lpcf->lpLogFont->lfHeight) * 10;
+      fResult = TRUE;
+    }
+  gtk_widget_destroy (dialog);
+  return fResult;
 }
 
 
@@ -256,6 +528,9 @@ commdlg_GetFileNameA (LPOPENFILENAMEA lpofn,
 {
   gchar *title;
   GtkWidget *dialog, *check = NULL;
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkWidget *parent;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   BOOL fResult = FALSE;
 
   if (!lpofn || !lpofn->lpstrFile)
@@ -276,8 +551,12 @@ commdlg_GetFileNameA (LPOPENFILENAMEA lpofn,
                                                 lpofn->Flags & OFN_READONLY);
     }
 #if GTK_CHECK_VERSION(2,4,0)
+  for (parent = lpofn->hwndOwner; parent;
+                                    parent = gtk_widget_get_parent (parent))
+    if (GTK_IS_WINDOW (parent))
+      break;
   dialog = gtk_file_chooser_dialog_new (title,
-        lpofn->hwndOwner ? GTK_WINDOW (lpofn->hwndOwner) : NULL,
+        parent ? GTK_WINDOW (parent) : NULL,
         opendlg ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE,
         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
         opendlg ? GTK_STOCK_OPEN : GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
@@ -485,6 +764,9 @@ commdlg_GetFileNameW (LPOPENFILENAMEW lpofn,
 {
   gchar *title;
   GtkWidget *dialog, *check = NULL;
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkWidget *parent;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   BOOL fResult = FALSE;
 
   if (!lpofn || !lpofn->lpstrFile)
@@ -506,8 +788,12 @@ commdlg_GetFileNameW (LPOPENFILENAMEW lpofn,
                                                 lpofn->Flags & OFN_READONLY);
     }
 #if GTK_CHECK_VERSION(2,4,0)
+  for (parent = lpofn->hwndOwner; parent;
+                                    parent = gtk_widget_get_parent (parent))
+    if (GTK_IS_WINDOW (parent))
+      break;
   dialog = gtk_file_chooser_dialog_new (title,
-        lpofn->hwndOwner ? GTK_WINDOW (lpofn->hwndOwner) : NULL,
+        parent ? GTK_WINDOW (parent) : NULL,
         opendlg ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE,
         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
         opendlg ? GTK_STOCK_OPEN : GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
@@ -525,11 +811,11 @@ commdlg_GetFileNameW (LPOPENFILENAMEW lpofn,
           GtkFileFilter *filter;
 
           filter = gtk_file_filter_new ();
-          text = wc ? g_utf16_to_utf8 (wc, -1, NULL, NULL, NULL) : NULL;
+          text = g_utf16_to_utf8 (wc, -1, NULL, NULL, NULL);
           wc += lstrlenW (wc) + 1;
           gtk_file_filter_set_name (filter, text);
           g_free (text);
-          text = wc ? g_utf16_to_utf8 (wc, -1, NULL, NULL, NULL) : NULL;
+          text = g_utf16_to_utf8 (wc, -1, NULL, NULL, NULL);
           wc += lstrlenW (wc) + 1;
           ext = g_strsplit (text, ";", 0);
           g_free (text);
@@ -831,8 +1117,8 @@ static DWORD WINAPI dwOKSubclass (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, D
 W32LdrExport commdlg_exports[] = {
 {FALSE, 101, "ChooseColorA",                      ChooseColorA},
 {FALSE, 102, "ChooseColorW",                      ChooseColorW},
-{FALSE, 103, "ChooseFontA",                       ChooseFontA},
-{FALSE, 104, "ChooseFontW",                       ChooseFontW},
+{TRUE,  103, "ChooseFontA",                       ChooseFontA},
+{TRUE,  104, "ChooseFontW",                       ChooseFontW},
 {FALSE, 105, "CommDlgExtendedError",              CommDlgExtendedError},
 {FALSE, 106, "FindTextA",                         FindTextA},
 {FALSE, 107, "FindTextW",                         FindTextW},
