@@ -29,6 +29,7 @@ extern "C" {
 
 
 #include "misc/fileio.h"
+
 /* ja:一般 */
 #define MAX_PATH 260
 #define INVALID_HANDLE_VALUE (GINT_TO_POINTER(-1))
@@ -37,12 +38,14 @@ extern "C" {
 #define LOAD_WITH_ALTERED_SEARCH_PATH 0x00000008
 typedef LPVOID LPCRITICAL_SECTION;
 typedef INT CALLBACK (*FARPROC)();
+
 /* ja:ウエイト */
 #define WAIT_FAILED    0xffffffff
 #define WAIT_OBJECT_0  0x00000000
 #define WAIT_ABANDONED 0x00000080
 #define WAIT_TIMEOUT   0x00000102
 #define INFINITE       0xffffffff
+
 /* ja:プロセス */
 #include "pshpack1.h"
 typedef struct _PROCESS_INFORMATION
@@ -102,6 +105,7 @@ typedef struct _STARTUPINFOW
 # define STARTUPINFO STARTUPINFOA
 # define LPSTARTUPINFO LPSTARTUPINFOA
 #endif /* not UNICODE */
+
 /* ja:メモリ */
 #define GMEM_FIXED          0x0000
 #define GMEM_MOVEABLE       0x0002
@@ -159,6 +163,7 @@ typedef struct tagMEMORYSTATUS
   SIZE_T dwAvailVirtual;
 } MEMORYSTATUS, *PMEMORYSTATUS, *LPMEMORYSTATUS;
 #include "poppack.h"
+
 /* ja:ファイル */
 #define STD_INPUT_HANDLE         (-10)
 #define STD_OUTPUT_HANDLE        (-11)
@@ -226,7 +231,7 @@ typedef FileIO *HFILE;
 typedef struct _WIN32_FIND_DATAA
 {
   DWORD dwFileAttributes;
-  FILETIME ftCreateTime;
+  FILETIME ftCreationTime;
   FILETIME ftLastAccessTime;
   FILETIME ftLastWriteTime;
   DWORD nFileSizeHigh;
@@ -239,7 +244,7 @@ typedef struct _WIN32_FIND_DATAA
 typedef struct _WIN32_FIND_DATAW
 {
   DWORD dwFileAttributes;
-  FILETIME ftCreateTime;
+  FILETIME ftCreationTime;
   FILETIME ftLastAccessTime;
   FILETIME ftLastWriteTime;
   DWORD nFileSizeHigh;
@@ -259,6 +264,7 @@ typedef struct _WIN32_FIND_DATAW
 # define PWIN32_FIND_DATA PWIN32_FIND_DATAA
 # define LPWIN32_FIND_DATA LPWIN32_FIND_DATAA
 #endif /* not UNICODE */
+
 /* ja:言語/ロケール/コードページ */
 #define MAX_DEFAULTCHAR 2
 #define MAX_LEADBYTES   12
@@ -279,192 +285,192 @@ typedef struct _WIN32_FIND_DATAW
 #define SUBLANGID(l)         ((WORD)(l)>>10)
 #define LANGIDFROMLCID(lcid) ((WORD)(lcid))
 #define SORTIDFROMLCID(lcid) ((WORD)((((DWORD)(lcid))>>16)&0x0f))
-#define LANG_MAIN_NEUTRAL                0x00
-#define LANG_MAIN_AFRIKAANS              0x36
-#define LANG_MAIN_ALBANIAN               0x1c
-#define LANG_MAIN_ARABIC                 0x01
-#define LANG_MAIN_ARMENIAN               0x2b
-#define LANG_MAIN_ASSAMESE               0x4d
-#define LANG_MAIN_AZERI                  0x2c
-#define LANG_MAIN_BASQUE                 0x2d
-#define LANG_MAIN_BENGALI                0x45
-#define LANG_MAIN_BULGARIAN              0x02
-#define LANG_MAIN_BYELORUSSIAN           0x23
-#define LANG_MAIN_CATALAN                0x03
-#define LANG_MAIN_CHINESE                0x04
-#define LANG_MAIN_SERBO_CROATIAN         0x1a
-#define LANG_MAIN_CROATIAN               LANG_MAIN_SERBO_CROATIAN
-#define LANG_MAIN_SERBIAN                LANG_MAIN_SERBO_CROATIAN
-#define LANG_MAIN_CZECH                  0x05
-#define LANG_MAIN_DANISH                 0x06
-#define LANG_MAIN_DUTCH                  0x13
-#define LANG_MAIN_ENGLISH                0x09
-#define LANG_MAIN_ESTONIAN               0x25
-#define LANG_MAIN_FAEROESE               0x38
-#define LANG_MAIN_FARSI                  0x29
-#define LANG_MAIN_FINNISH                0x0b
-#define LANG_MAIN_FRENCH                 0x0c
-#define LANG_MAIN_GAELIC                 0x3c
-#define LANG_MAIN_GEORGIAN               0x37
-#define LANG_MAIN_GERMAN                 0x07
-#define LANG_MAIN_GREEK                  0x08
-#define LANG_MAIN_GUJARATI               0x47
-#define LANG_MAIN_HEBREW                 0x0d
-#define LANG_MAIN_HINDI                  0x39
-#define LANG_MAIN_HUNGARIAN              0x0e
-#define LANG_MAIN_ICELANDIC              0x0f
-#define LANG_MAIN_INDONESIAN             0x21
-#define LANG_MAIN_ITALIAN                0x10
-#define LANG_MAIN_JAPANESE               0x11
-#define LANG_MAIN_KANNADA                0x4b
-#define LANG_MAIN_KAZAKH                 0x3f
-#define LANG_MAIN_KONKANI                0x57
-#define LANG_MAIN_KOREAN                 0x12
-#define LANG_MAIN_LATVIAN                0x26
-#define LANG_MAIN_LITHUANIAN             0x27
-#define LANG_MAIN_MACEDONIAN             0x2f
-#define LANG_MAIN_MALAY                  0x3e
-#define LANG_MAIN_MALAYALAM              0x4c
-#define LANG_MAIN_MALTESE                0x3a
-#define LANG_MAIN_MAORI                  0x28
-#define LANG_MAIN_MARATHI                0x4e
-#define LANG_MAIN_NORWEGIAN              0x14
-#define LANG_MAIN_ORIYA                  0x48
-#define LANG_MAIN_POLISH                 0x15
-#define LANG_MAIN_PORTUGUESE             0x16
-#define LANG_MAIN_PUNJABI                0x46
-#define LANG_MAIN_RHAETO_ROMANCE         0x17
-#define LANG_MAIN_ROMANIAN               0x18
-#define LANG_MAIN_RUSSIAN                0x19
-#define LANG_MAIN_SAAMI                  0x3b
-#define LANG_MAIN_SANSKRIT               0x4f
-#define LANG_MAIN_SLOVAK                 0x1b
-#define LANG_MAIN_SLOVENIAN              0x24
-#define LANG_MAIN_SORBIAN                0x2e
-#define LANG_MAIN_SPANISH                0x0a
-#define LANG_MAIN_SUTU                   0x30
-#define LANG_MAIN_SWAHILI                0x41
-#define LANG_MAIN_SWEDISH                0x1d
-#define LANG_MAIN_TAMIL                  0x49
-#define LANG_MAIN_TATAR                  0x44
-#define LANG_MAIN_TELUGU                 0x4a
-#define LANG_MAIN_THAI                   0x1e
-#define LANG_MAIN_TSONGA                 0x31
-#define LANG_MAIN_TSWANA                 0x32
-#define LANG_MAIN_TURKISH                0x1f
-#define LANG_MAIN_UKRAINIAN              0x22
-#define LANG_MAIN_URDU                   0x20
-#define LANG_MAIN_UZBEK                  0x43
-#define LANG_MAIN_VENDA                  0x33
-#define LANG_MAIN_VIETNAMESE             0x2a
-#define LANG_MAIN_XHOSA                  0x34
-#define LANG_MAIN_ZULU                   0x35
-#define LANG_MAIN_ESPERANTO              0x8f
-#define LANG_MAIN_WALON                  0x90
-#define LANG_MAIN_CORNISH                0x91
-#define LANG_MAIN_WELSH                  0x92
-#define LANG_MAIN_BRETON                 0x93
-#define LANG_SUB_NEUTRAL                 0x00
-#define LANG_SUB_DEFAULT                 0x01
-#define LANG_SUB_SYS_DEFAULT             0x02
-#define LANG_SUB_ARABIC                  0x01
-#define LANG_SUB_ARABIC_SAUDI_ARABIA     0x01
-#define LANG_SUB_ARABIC_IRAQ             0x02
-#define LANG_SUB_ARABIC_EGYPT            0x03
-#define LANG_SUB_ARABIC_LIBYA            0x04
-#define LANG_SUB_ARABIC_ALGERIA          0x05
-#define LANG_SUB_ARABIC_MOROCCO          0x06
-#define LANG_SUB_ARABIC_TUNISIA          0x07
-#define LANG_SUB_ARABIC_OMAN             0x08
-#define LANG_SUB_ARABIC_YEMEN            0x09
-#define LANG_SUB_ARABIC_SYRIA            0x0a
-#define LANG_SUB_ARABIC_JORDAN           0x0b
-#define LANG_SUB_ARABIC_LEBANON          0x0c
-#define LANG_SUB_ARABIC_KUWAIT           0x0d
-#define LANG_SUB_ARABIC_UAE              0x0e
-#define LANG_SUB_ARABIC_BAHRAIN          0x0f
-#define LANG_SUB_ARABIC_QATAR            0x10
-#define LANG_SUB_CHINESE_TRADITIONAL     0x01
-#define LANG_SUB_CHINESE_SIMPLIFIED      0x02
-#define LANG_SUB_CHINESE_HONGKONG        0x03
-#define LANG_SUB_CHINESE_SINGAPORE       0x04
-#define LANG_SUB_CHINESE_MACAU           0x05
-#define LANG_SUB_DUTCH                   0x01
-#define LANG_SUB_DUTCH_BELGIAN           0x02
-#define LANG_SUB_DUTCH_SURINAM           0x03
-#define LANG_SUB_ENGLISH_US              0x01
-#define LANG_SUB_ENGLISH_UK              0x02
-#define LANG_SUB_ENGLISH_AUS             0x03
-#define LANG_SUB_ENGLISH_CAN             0x04
-#define LANG_SUB_ENGLISH_NZ              0x05
-#define LANG_SUB_ENGLISH_EIRE            0x06
-#define LANG_SUB_ENGLISH_SAFRICA         0x07
-#define LANG_SUB_ENGLISH_JAMAICA         0x08
-#define LANG_SUB_ENGLISH_CARRIBEAN       0x09
-#define LANG_SUB_ENGLISH_BELIZE          0x0a
-#define LANG_SUB_ENGLISH_TRINIDAD        0x0b
-#define LANG_SUB_ENGLISH_ZIMBABWE        0x0c
-#define LANG_SUB_ENGLISH_PHILIPPINES     0x0d
-#define LANG_SUB_FRENCH                  0x01
-#define LANG_SUB_FRENCH_BELGIAN          0x02
-#define LANG_SUB_FRENCH_CANADIAN         0x03
-#define LANG_SUB_FRENCH_SWISS            0x04
-#define LANG_SUB_FRENCH_LUXEMBOURG       0x05
-#define LANG_SUB_FRENCH_MONACO           0x06
-#define LANG_SUB_GERMAN                  0x01
-#define LANG_SUB_GERMAN_SWISS            0x02
-#define LANG_SUB_GERMAN_AUSTRIAN         0x03
-#define LANG_SUB_GERMAN_LUXEMBOURG       0x04
-#define LANG_SUB_GERMAN_LIECHTENSTEIN    0x05
-#define LANG_SUB_ITALIAN                 0x01
-#define LANG_SUB_ITALIAN_SWISS           0x02
-#define LANG_SUB_KOREAN                  0x01
-#define LANG_SUB_KOREAN_JOHAB            0x02
-#define LANG_SUB_NORWEGIAN_BOKMAL        0x01
-#define LANG_SUB_NORWEGIAN_NYNORSK       0x02
-#define LANG_SUB_PORTUGUESE              0x02
-#define LANG_SUB_PORTUGUESE_BRAZILIAN    0x01
-#define LANG_SUB_SPANISH                 0x01
-#define LANG_SUB_SPANISH_MEXICAN         0x02
-#define LANG_SUB_SPANISH_MODERN          0x03
-#define LANG_SUB_SPANISH_GUATEMALA       0x04
-#define LANG_SUB_SPANISH_COSTARICA       0x05
-#define LANG_SUB_SPANISH_PANAMA          0x06
-#define LANG_SUB_SPANISH_DOMINICAN       0x07
-#define LANG_SUB_SPANISH_VENEZUELA       0x08
-#define LANG_SUB_SPANISH_COLOMBIA        0x09
-#define LANG_SUB_SPANISH_PERU            0x0a
-#define LANG_SUB_SPANISH_ARGENTINA       0x0b
-#define LANG_SUB_SPANISH_ECUADOR         0x0c
-#define LANG_SUB_SPANISH_CHILE           0x0d
-#define LANG_SUB_SPANISH_URUGUAY         0x0e
-#define LANG_SUB_SPANISH_PARAGUAY        0x0f
-#define LANG_SUB_SPANISH_BOLIVIA         0x10
-#define LANG_SUB_SPANISH_EL_SALVADOR     0x11
-#define LANG_SUB_SPANISH_HONDURAS        0x12
-#define LANG_SUB_SPANISH_NICARAGUA       0x13
-#define LANG_SUB_SPANISH_PUERTO_RICO     0x14
-#define LANG_SUB_ROMANIAN                0x01
-#define LANG_SUB_ROMANIAN_MOLDAVIA       0x02
-#define LANG_SUB_RUSSIAN                 0x01
-#define LANG_SUB_RUSSIAN_MOLDAVIA        0x02
-#define LANG_SUB_CROATIAN                0x01
-#define LANG_SUB_SERBIAN                 0x02
-#define LANG_SUB_SERBIAN_LATIN           0x03
-#define LANG_SUB_SWEDISH                 0x01
-#define LANG_SUB_SWEDISH_FINLAND         0x02
-#define LANG_SUB_LITHUANIAN              0x01
-#define LANG_SUB_LITHUANIAN_CLASSIC      0x02
-#define LANG_SUB_AZERI                   0x01
-#define LANG_SUB_AZERI_CYRILLIC          0x02
-#define LANG_SUB_GAELIC                  0x01
-#define LANG_SUB_GAELIC_SCOTTISH         0x02
-#define LANG_SUB_GAELIC_MANX             0x03
-#define LANG_SUB_MALAY                   0x01
-#define LANG_SUB_MALAY_BRUNEI_DARUSSALAM 0x02
-#define LANG_SUB_UZBEK                   0x01
-#define LANG_SUB_UZBEK_CYRILLIC          0x02
-#define LANG_SUB_URDU_PAKISTAN           0x01
+#define LANG_NEUTRAL                0x00
+#define LANG_AFRIKAANS              0x36
+#define LANG_ALBANIAN               0x1c
+#define LANG_ARABIC                 0x01
+#define LANG_ARMENIAN               0x2b
+#define LANG_ASSAMESE               0x4d
+#define LANG_AZERI                  0x2c
+#define LANG_BASQUE                 0x2d
+#define LANG_BENGALI                0x45
+#define LANG_BULGARIAN              0x02
+#define LANG_BYELORUSSIAN           0x23
+#define LANG_CATALAN                0x03
+#define LANG_CHINESE                0x04
+#define LANG_SERBO_CROATIAN         0x1a
+#define LANG_CROATIAN               LANG_SERBO_CROATIAN
+#define LANG_SERBIAN                LANG_SERBO_CROATIAN
+#define LANG_CZECH                  0x05
+#define LANG_DANISH                 0x06
+#define LANG_DUTCH                  0x13
+#define LANG_ENGLISH                0x09
+#define LANG_ESTONIAN               0x25
+#define LANG_FAEROESE               0x38
+#define LANG_FARSI                  0x29
+#define LANG_FINNISH                0x0b
+#define LANG_FRENCH                 0x0c
+#define LANG_GAELIC                 0x3c
+#define LANG_GEORGIAN               0x37
+#define LANG_GERMAN                 0x07
+#define LANG_GREEK                  0x08
+#define LANG_GUJARATI               0x47
+#define LANG_HEBREW                 0x0d
+#define LANG_HINDI                  0x39
+#define LANG_HUNGARIAN              0x0e
+#define LANG_ICELANDIC              0x0f
+#define LANG_INDONESIAN             0x21
+#define LANG_ITALIAN                0x10
+#define LANG_JAPANESE               0x11
+#define LANG_KANNADA                0x4b
+#define LANG_KAZAKH                 0x3f
+#define LANG_KONKANI                0x57
+#define LANG_KOREAN                 0x12
+#define LANG_LATVIAN                0x26
+#define LANG_LITHUANIAN             0x27
+#define LANG_MACEDONIAN             0x2f
+#define LANG_MALAY                  0x3e
+#define LANG_MALAYALAM              0x4c
+#define LANG_MALTESE                0x3a
+#define LANG_MAORI                  0x28
+#define LANG_MARATHI                0x4e
+#define LANG_NORWEGIAN              0x14
+#define LANG_ORIYA                  0x48
+#define LANG_POLISH                 0x15
+#define LANG_PORTUGUESE             0x16
+#define LANG_PUNJABI                0x46
+#define LANG_RHAETO_ROMANCE         0x17
+#define LANG_ROMANIAN               0x18
+#define LANG_RUSSIAN                0x19
+#define LANG_SAAMI                  0x3b
+#define LANG_SANSKRIT               0x4f
+#define LANG_SLOVAK                 0x1b
+#define LANG_SLOVENIAN              0x24
+#define LANG_SORBIAN                0x2e
+#define LANG_SPANISH                0x0a
+#define LANG_SUTU                   0x30
+#define LANG_SWAHILI                0x41
+#define LANG_SWEDISH                0x1d
+#define LANG_TAMIL                  0x49
+#define LANG_TATAR                  0x44
+#define LANG_TELUGU                 0x4a
+#define LANG_THAI                   0x1e
+#define LANG_TSONGA                 0x31
+#define LANG_TSWANA                 0x32
+#define LANG_TURKISH                0x1f
+#define LANG_UKRAINIAN              0x22
+#define LANG_URDU                   0x20
+#define LANG_UZBEK                  0x43
+#define LANG_VENDA                  0x33
+#define LANG_VIETNAMESE             0x2a
+#define LANG_XHOSA                  0x34
+#define LANG_ZULU                   0x35
+#define LANG_ESPERANTO              0x8f
+#define LANG_WALON                  0x90
+#define LANG_CORNISH                0x91
+#define LANG_WELSH                  0x92
+#define LANG_BRETON                 0x93
+#define SUBLANG_NEUTRAL                 0x00
+#define SUBLANG_DEFAULT                 0x01
+#define SUBLANG_SYS_DEFAULT             0x02
+#define SUBLANG_ARABIC                  0x01
+#define SUBLANG_ARABIC_SAUDI_ARABIA     0x01
+#define SUBLANG_ARABIC_IRAQ             0x02
+#define SUBLANG_ARABIC_EGYPT            0x03
+#define SUBLANG_ARABIC_LIBYA            0x04
+#define SUBLANG_ARABIC_ALGERIA          0x05
+#define SUBLANG_ARABIC_MOROCCO          0x06
+#define SUBLANG_ARABIC_TUNISIA          0x07
+#define SUBLANG_ARABIC_OMAN             0x08
+#define SUBLANG_ARABIC_YEMEN            0x09
+#define SUBLANG_ARABIC_SYRIA            0x0a
+#define SUBLANG_ARABIC_JORDAN           0x0b
+#define SUBLANG_ARABIC_LEBANON          0x0c
+#define SUBLANG_ARABIC_KUWAIT           0x0d
+#define SUBLANG_ARABIC_UAE              0x0e
+#define SUBLANG_ARABIC_BAHRAIN          0x0f
+#define SUBLANG_ARABIC_QATAR            0x10
+#define SUBLANG_CHINESE_TRADITIONAL     0x01
+#define SUBLANG_CHINESE_SIMPLIFIED      0x02
+#define SUBLANG_CHINESE_HONGKONG        0x03
+#define SUBLANG_CHINESE_SINGAPORE       0x04
+#define SUBLANG_CHINESE_MACAU           0x05
+#define SUBLANG_DUTCH                   0x01
+#define SUBLANG_DUTCH_BELGIAN           0x02
+#define SUBLANG_DUTCH_SURINAM           0x03
+#define SUBLANG_ENGLISH_US              0x01
+#define SUBLANG_ENGLISH_UK              0x02
+#define SUBLANG_ENGLISH_AUS             0x03
+#define SUBLANG_ENGLISH_CAN             0x04
+#define SUBLANG_ENGLISH_NZ              0x05
+#define SUBLANG_ENGLISH_EIRE            0x06
+#define SUBLANG_ENGLISH_SAFRICA         0x07
+#define SUBLANG_ENGLISH_JAMAICA         0x08
+#define SUBLANG_ENGLISH_CARRIBEAN       0x09
+#define SUBLANG_ENGLISH_BELIZE          0x0a
+#define SUBLANG_ENGLISH_TRINIDAD        0x0b
+#define SUBLANG_ENGLISH_ZIMBABWE        0x0c
+#define SUBLANG_ENGLISH_PHILIPPINES     0x0d
+#define SUBLANG_FRENCH                  0x01
+#define SUBLANG_FRENCH_BELGIAN          0x02
+#define SUBLANG_FRENCH_CANADIAN         0x03
+#define SUBLANG_FRENCH_SWISS            0x04
+#define SUBLANG_FRENCH_LUXEMBOURG       0x05
+#define SUBLANG_FRENCH_MONACO           0x06
+#define SUBLANG_GERMAN                  0x01
+#define SUBLANG_GERMAN_SWISS            0x02
+#define SUBLANG_GERMAN_AUSTRIAN         0x03
+#define SUBLANG_GERMAN_LUXEMBOURG       0x04
+#define SUBLANG_GERMAN_LIECHTENSTEIN    0x05
+#define SUBLANG_ITALIAN                 0x01
+#define SUBLANG_ITALIAN_SWISS           0x02
+#define SUBLANG_KOREAN                  0x01
+#define SUBLANG_KOREAN_JOHAB            0x02
+#define SUBLANG_NORWEGIAN_BOKMAL        0x01
+#define SUBLANG_NORWEGIAN_NYNORSK       0x02
+#define SUBLANG_PORTUGUESE              0x02
+#define SUBLANG_PORTUGUESE_BRAZILIAN    0x01
+#define SUBLANG_SPANISH                 0x01
+#define SUBLANG_SPANISH_MEXICAN         0x02
+#define SUBLANG_SPANISH_MODERN          0x03
+#define SUBLANG_SPANISH_GUATEMALA       0x04
+#define SUBLANG_SPANISH_COSTARICA       0x05
+#define SUBLANG_SPANISH_PANAMA          0x06
+#define SUBLANG_SPANISH_DOMINICAN       0x07
+#define SUBLANG_SPANISH_VENEZUELA       0x08
+#define SUBLANG_SPANISH_COLOMBIA        0x09
+#define SUBLANG_SPANISH_PERU            0x0a
+#define SUBLANG_SPANISH_ARGENTINA       0x0b
+#define SUBLANG_SPANISH_ECUADOR         0x0c
+#define SUBLANG_SPANISH_CHILE           0x0d
+#define SUBLANG_SPANISH_URUGUAY         0x0e
+#define SUBLANG_SPANISH_PARAGUAY        0x0f
+#define SUBLANG_SPANISH_BOLIVIA         0x10
+#define SUBLANG_SPANISH_EL_SALVADOR     0x11
+#define SUBLANG_SPANISH_HONDURAS        0x12
+#define SUBLANG_SPANISH_NICARAGUA       0x13
+#define SUBLANG_SPANISH_PUERTO_RICO     0x14
+#define SUBLANG_ROMANIAN                0x01
+#define SUBLANG_ROMANIAN_MOLDAVIA       0x02
+#define SUBLANG_RUSSIAN                 0x01
+#define SUBLANG_RUSSIAN_MOLDAVIA        0x02
+#define SUBLANG_CROATIAN                0x01
+#define SUBLANG_SERBIAN                 0x02
+#define SUBLANG_SERBIAN_LATIN           0x03
+#define SUBLANG_SWEDISH                 0x01
+#define SUBLANG_SWEDISH_FINLAND         0x02
+#define SUBLANG_LITHUANIAN              0x01
+#define SUBLANG_LITHUANIAN_CLASSIC      0x02
+#define SUBLANG_AZERI                   0x01
+#define SUBLANG_AZERI_CYRILLIC          0x02
+#define SUBLANG_GAELIC                  0x01
+#define SUBLANG_GAELIC_SCOTTISH         0x02
+#define SUBLANG_GAELIC_MANX             0x03
+#define SUBLANG_MALAY                   0x01
+#define SUBLANG_MALAY_BRUNEI_DARUSSALAM 0x02
+#define SUBLANG_UZBEK                   0x01
+#define SUBLANG_UZBEK_CYRILLIC          0x02
+#define SUBLANG_URDU_PAKISTAN           0x01
 typedef WORD LANGID;
 typedef DWORD CALID;
 typedef DWORD CALTYPE;
@@ -511,6 +517,7 @@ typedef struct
 # define CPINFOEX CPINFOEXA
 # define LPCPINFOEX LPCPINFOEXA
 #endif /* not UNICODE */
+
 /* ja:環境 */
 #define VER_PLATFORM_WIN32s        0
 #define VER_PLATFORM_WIN32_WINDOWS 1
@@ -630,6 +637,7 @@ typedef struct _SYSTEMTIME
   WORD wMilliseconds;
 } SYSTEMTIME, *PSYSTEMTIME, *LPSYSTEMTIME;
 #include "poppack.h"
+
 /* ja:コンソール */
 #include "pshpack1.h"
 typedef struct tagCOORD
@@ -637,6 +645,7 @@ typedef struct tagCOORD
   SHORT X;
   SHORT Y;
 } COORD, *PCOORD, *LPCOORD;
+
 /* ja:非公開 */
 #define EXCEPTION_MAXIMUM_PARAMETERS 15
 typedef struct _EXCEPTION_RECORD
