@@ -711,7 +711,7 @@ static DWORD WINAPI SHBindToParent (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2,
 
 
 static LPITEMIDLIST
-shell_filename_to_idl (const gchar *file)
+shell32_filename_to_idl (const gchar *file)
 {
   LPITEMIDLIST pidl = NULL;
 
@@ -750,6 +750,9 @@ LPITEMIDLIST WINAPI SHBrowseForFolderA (LPBROWSEINFOA lpbi)
 {
   gchar *title, *path;
   GtkWidget *dialog;
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkWidget *parent;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   LPITEMIDLIST pidl = NULL;
 
   if (!lpbi || (lpbi->ulFlags & (BIF_BROWSEFORCOMPUTER | BIF_BROWSEFORPRINTER
@@ -757,8 +760,12 @@ LPITEMIDLIST WINAPI SHBrowseForFolderA (LPBROWSEINFOA lpbi)
     return NULL;
   title = w32ldr_utf8_from_mb (lpbi->lpszTitle);
 #if GTK_CHECK_VERSION(2,4,0)
+  for (parent = lpbi->hwndOwner; parent;
+                                    parent = gtk_widget_get_parent (parent))
+    if (GTK_IS_WINDOW (parent))
+      break;
   dialog = gtk_file_chooser_dialog_new (title,
-                        GTK_WINDOW (lpbi->hwndOwner),
+                        parent ? GTK_WINDOW (parent) : NULL,
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
@@ -785,7 +792,7 @@ LPITEMIDLIST WINAPI SHBrowseForFolderA (LPBROWSEINFOA lpbi)
       mb = w32ldr_filename_to_mb (path);
       g_strcpy (lpbi->pszDisplayName, mb);
       g_free (mb);
-      pidl = shell_filename_to_idl (path);
+      pidl = shell32_filename_to_idl (path);
       g_free (path);
       lpbi->iImage = 0;
     }
@@ -798,6 +805,9 @@ LPITEMIDLIST WINAPI SHBrowseForFolderW (LPBROWSEINFOW lpbi)
 {
   gchar *title, *path;
   GtkWidget *dialog;
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkWidget *parent;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   LPITEMIDLIST pidl = NULL;
 
   if (!lpbi || (lpbi->ulFlags & (BIF_BROWSEFORCOMPUTER | BIF_BROWSEFORPRINTER
@@ -806,8 +816,12 @@ LPITEMIDLIST WINAPI SHBrowseForFolderW (LPBROWSEINFOW lpbi)
   title = lpbi->lpszTitle ? g_utf16_to_utf8 (lpbi->lpszTitle, -1,
                                                     NULL, NULL, NULL) : NULL;
 #if GTK_CHECK_VERSION(2,4,0)
+  for (parent = lpbi->hwndOwner; parent;
+                                    parent = gtk_widget_get_parent (parent))
+    if (GTK_IS_WINDOW (parent))
+      break;
   dialog = gtk_file_chooser_dialog_new (title,
-                        GTK_WINDOW (lpbi->hwndOwner),
+                        parent ? GTK_WINDOW (parent) : NULL,
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
@@ -834,7 +848,7 @@ LPITEMIDLIST WINAPI SHBrowseForFolderW (LPBROWSEINFOW lpbi)
       wc = w32ldr_filename_to_wc (path);
       lstrcpyW (lpbi->pszDisplayName, wc);
       g_free (wc);
-      pidl = shell_filename_to_idl (path);
+      pidl = shell32_filename_to_idl (path);
       g_free (path);
       lpbi->iImage = 0;
     }
@@ -917,13 +931,13 @@ INT WINAPI SHFileOperationA (LPSHFILEOPSTRUCTA lpFileOp)
     {
       gchar *file, *dir;
       LPSTR lpszSrc, lpszSrcName, lpszDst = NULL, lpszDstName = NULL;
-      HANDLE hFile;
+      HANDLE hFind;
       WIN32_FIND_DATAA wfData;
 
       if (mb_to && *mb_to == '\0')
         return 0;
-      hFile = FindFirstFileA (mb_from, &wfData);
-      if (hFile == INVALID_HANDLE_VALUE)
+      hFind = FindFirstFileA (mb_from, &wfData);
+      if (hFind == INVALID_HANDLE_VALUE)
         return 0;
       file = w32ldr_filename_from_mb (mb_from);
       dir = g_path_get_dirname (file);
@@ -966,8 +980,8 @@ INT WINAPI SHFileOperationA (LPSHFILEOPSTRUCTA lpFileOp)
                 result = FALSE;
             }
         }
-      while (result && FindNextFileA (hFile, &wfData));
-      FindClose (hFile);
+      while (result && FindNextFileA (hFind, &wfData));
+      FindClose (hFind);
       g_free (lpszSrc);
       g_free (lpszDst);
       if (mb_to && (lpFileOp->fFlags & FOF_MULTIDESTFILES))
@@ -992,14 +1006,14 @@ INT WINAPI SHFileOperationW (LPSHFILEOPSTRUCTW lpFileOp)
     {
       gchar *file, *dir;
       LPWSTR lpszSrc, lpszSrcName, lpszDst = NULL, lpszDstName = NULL;
-      HANDLE hFile;
+      HANDLE hFind;
       WIN32_FIND_DATAW wfData;
       CONST WCHAR wSep[2] = {'\\', '\0'};
 
       if (wc_to && *wc_to == '\0')
         return 0;
-      hFile = FindFirstFileW (wc_from, &wfData);
-      if (hFile == INVALID_HANDLE_VALUE)
+      hFind = FindFirstFileW (wc_from, &wfData);
+      if (hFind == INVALID_HANDLE_VALUE)
         return 0;
       file = w32ldr_filename_from_wc (wc_from);
       dir = g_path_get_dirname (file);
@@ -1042,8 +1056,8 @@ INT WINAPI SHFileOperationW (LPSHFILEOPSTRUCTW lpFileOp)
                 result = FALSE;
             }
         }
-      while (result && FindNextFileW (hFile, &wfData));
-      FindClose (hFile);
+      while (result && FindNextFileW (hFind, &wfData));
+      FindClose (hFind);
       g_free (lpszSrc);
       g_free (lpszDst);
       if (wc_to && (lpFileOp->fFlags & FOF_MULTIDESTFILES))
