@@ -35,8 +35,6 @@ extern "C" {
 #include "w32list.h"
 #include "w32sbar.h"
 #include "w32combo.h"
-#include "w32dlg.h"
-#include "w32wnd.h"
 
 /* ja:システム */
 #define COLOR_SCROLLBAR               0
@@ -311,30 +309,112 @@ typedef struct _PAINTSTRUCT
 #define IMAGE_ICON        1
 #define IMAGE_CURSOR      2
 #define IMAGE_ENHMETAFILE 3
+#define LR_DEFAULTCOLOR     0x0000
+#define LR_MONOCHROME       0x0001
+#define LR_COLOR            0x0002
+#define LR_COPYRETURNORG    0x0004
+#define LR_COPYDELETEORG    0x0008
+#define LR_LOADFROMFILE     0x0010
+#define LR_LOADTRANSPARENT  0x0020
+#define LR_DEFAULTSIZE      0x0040
+#define LR_VGA_COLOR        0x0080
+#define LR_LOADMAP3DCOLORS  0x1000
+#define LR_CREATEDIBSECTION 0x2000
+#define LR_COPYFROMRESOURCE 0x4000
+#define LR_SHARED           0x8000
 
 /* ja:アイコン */
-typedef LPVOID HICON;
+#define OIC_SAMPLE      32512
+#define OIC_HAND        32513
+#define OIC_ERROR       OIC_HAND
+#define OIC_QUES        32514
+#define OIC_BANG        32515
+#define OIC_WARNING     OIC_BANG
+#define OIC_NOTE        32516
+#define OIC_INFORMATION OIC_NOTE
+#define OIC_WINLOGO     32517
+#define IDI_APPLICATION MAKEINTRESOURCE(OIC_SAMPLE)
+#define IDI_HAND        MAKEINTRESOURCE(OIC_HAND)
+#define IDI_ERROR       IDI_HAND
+#define IDI_QUESTION    MAKEINTRESOURCE(OIC_QUES)
+#define IDI_EXCLAMATION MAKEINTRESOURCE(OIC_BANG)
+#define IDI_WARNING     IDI_EXCLAMATION
+#define IDI_ASTERISK    MAKEINTRESOURCE(OIC_NOTE)
+#define IDI_INFORMATION IDI_ASTERISK
+#define IDI_WINLOGO     MAKEINTRESOURCE(OIC_WINLOGO)
+typedef GdkPixbuf *HICON;
 
 /* ja:カーソル */
-#define IDC_ARROW       MAKEINTRESOURCE(32512)
-#define IDC_IBEAM       MAKEINTRESOURCE(32513)
-#define IDC_WAIT        MAKEINTRESOURCE(32514)
-#define IDC_CROSS       MAKEINTRESOURCE(32515)
-#define IDC_UPARROW     MAKEINTRESOURCE(32516)
-#define IDC_SIZE        MAKEINTRESOURCE(32640)
-#define IDC_ICON        MAKEINTRESOURCE(32641)
-#define IDC_SIZENWSE    MAKEINTRESOURCE(32642)
-#define IDC_SIZENESW    MAKEINTRESOURCE(32643)
-#define IDC_SIZEWE      MAKEINTRESOURCE(32644)
-#define IDC_SIZENS      MAKEINTRESOURCE(32645)
-#define IDC_SIZEALL     MAKEINTRESOURCE(32646)
-#define IDC_NO          MAKEINTRESOURCE(32648)
-#define IDC_HAND        MAKEINTRESOURCE(32649)
-#define IDC_APPSTARTING MAKEINTRESOURCE(32650)
-#define IDC_HELP        MAKEINTRESOURCE(32651)
-typedef LPVOID HCURSOR;
+#define OCR_NORMAL      32512
+#define OCR_IBEAM       32513
+#define OCR_WAIT        32514
+#define OCR_CROSS       32515
+#define OCR_UP          32516
+#define OCR_SIZE        32640
+#define OCR_ICON        32641
+#define OCR_SIZENWSE    32642
+#define OCR_SIZENESW    32643
+#define OCR_SIZEWE      32644
+#define OCR_SIZENS      32645
+#define OCR_SIZEALL     32646
+#define OCR_NO          32648
+#define OCR_HAND        32649
+#define OCR_APPSTARTING 32650
+#define OCR_HELP        32651
+#define IDC_ARROW       MAKEINTRESOURCE(OCR_NORMAL)
+#define IDC_IBEAM       MAKEINTRESOURCE(OCR_IBEAM)
+#define IDC_WAIT        MAKEINTRESOURCE(OCR_WAIT)
+#define IDC_CROSS       MAKEINTRESOURCE(OCR_CROSS)
+#define IDC_UPARROW     MAKEINTRESOURCE(OCR_UP)
+#define IDC_SIZE        MAKEINTRESOURCE(OCR_SIZE)
+#define IDC_ICON        MAKEINTRESOURCE(OCR_ICON)
+#define IDC_SIZENWSE    MAKEINTRESOURCE(OCR_SIZENWSE)
+#define IDC_SIZENESW    MAKEINTRESOURCE(OCR_SIZENESW)
+#define IDC_SIZEWE      MAKEINTRESOURCE(OCR_SIZEWE)
+#define IDC_SIZENS      MAKEINTRESOURCE(OCR_SIZENS)
+#define IDC_SIZEALL     MAKEINTRESOURCE(OCR_SIZEALL)
+#define IDC_NO          MAKEINTRESOURCE(OCR_NO)
+#define IDC_HAND        MAKEINTRESOURCE(OCR_HAND)
+#define IDC_APPSTARTING MAKEINTRESOURCE(OCR_APPSTARTING)
+#define IDC_HELP        MAKEINTRESOURCE(OCR_HELP)
+typedef GdkCursor *HCURSOR;
 
 /* ja:ビットマップ */
+#define OBM_TRTYPE      32732
+#define OBM_LFARROWI    32734
+#define OBM_RGARROWI    32735
+#define OBM_DNARROWI    32736
+#define OBM_UPARROWI    32737
+#define OBM_COMBO       32738
+#define OBM_MNARROW     32739
+#define OBM_LFARROWD    32740
+#define OBM_RGARROWD    32741
+#define OBM_DNARROWD    32742
+#define OBM_UPARROWD    32743
+#define OBM_RESTORED    32744
+#define OBM_ZOOMD       32745
+#define OBM_REDUCED     32746
+#define OBM_RESTORE     32747
+#define OBM_ZOOM        32748
+#define OBM_REDUCE      32749
+#define OBM_LFARROW     32750
+#define OBM_RGARROW     32751
+#define OBM_DNARROW     32752
+#define OBM_UPARROW     32753
+#define OBM_CLOSE       32754
+#define OBM_OLD_RESTORE 32755
+#define OBM_OLD_ZOOM    32756
+#define OBM_OLD_REDUCE  32757
+#define OBM_BTNCORNERS  32758
+#define OBM_CHECKBOXES  32759
+#define OBM_CHECK       32760
+#define OBM_BTSIZE      32761
+#define OBM_OLD_LFARROW 32762
+#define OBM_OLD_RGARROW 32763
+#define OBM_OLD_DNARROW 32764
+#define OBM_OLD_UPARROW 32765
+#define OBM_SIZE        32766
+#define OBM_OLD_CLOSE   32767
 typedef GdkPixbuf *HBITMAP;
 #include "pshpack1.h"
 typedef struct _BITMAPINFOHEADER
@@ -354,100 +434,194 @@ typedef struct _BITMAPINFOHEADER
 #include "poppack.h"
 
 /* ja:メニュー */
-#define MF_INSERT          0x00000000
-#define MF_CHANGE          0x00000080
-#define MF_APPEND          0x00000100
-#define MF_DELETE          0x00000200
-#define MF_REMOVE          0x00001000
-#define MF_BYCOMMAND       0x00000000
-#define MF_BYPOSITION      0x00000400
-#define MF_SEPARATOR       0x00000800
-#define MF_ENABLED         0x00000000
-#define MF_GRAYED          0x00000001
-#define MF_DISABLED        0x00000002
-#define MF_UNCHECKED       0x00000000
-#define MF_CHECKED         0x00000008
-#define MF_USECHECKBITMAPS 0x00000200
-#define MF_STRING          0x00000000
-#define MF_BITMAP          0x00000004
-#define MF_OWNERDRAW       0x00000100
-#define MF_POPUP           0x00000010
-#define MF_MENUBARBREAK    0x00000020
-#define MF_MENUBREAK       0x00000040
-#define MF_UNHILITE        0x00000000
-#define MF_HILITE          0x00000080
-#define MF_DEFAULT         0x00001000
-#define MF_SYSMENU         0x00002000
-#define MF_HELP            0x00004000
-#define MF_RIGHTJUSTIFY    0x00004000
-#define MF_MOUSESELECT     0x00008000
-#define MF_END             0x00000080
-#define MIIM_STATE      0x00000001
-#define MIIM_ID         0x00000002
-#define MIIM_SUBMENU    0x00000004
-#define MIIM_CHECKMARKS 0x00000008
-#define MIIM_TYPE       0x00000010
-#define MIIM_DATA       0x00000020
-#define MIIM_STRING     0x00000040
-#define MIIM_BITMAP     0x00000080
-#define MIIM_FTYPE      0x00000100
-#define TPM_LEFTBUTTON   0x0000
-#define TPM_RIGHTBUTTON  0x0002
-#define TPM_LEFTALIGN    0x0000
-#define TPM_CENTERALIGN  0x0004
-#define TPM_RIGHTALIGN   0x0008
-#define TPM_TOPALIGN     0x0000
-#define TPM_VCENTERALIGN 0x0010
-#define TPM_BOTTOMALIGN  0x0020
-#define TPM_HORIZONTAL   0x0000
-#define TPM_VERTICAL     0x0040
-#define TPM_RETURNCMD    0x0100
-typedef LPVOID HMENU;
-#include "pshpack1.h"
-typedef struct _MENUITEMINFOA
-{
-  UINT cbSize;
-  UINT fMask;
-  UINT fType;
-  UINT fState;
-  UINT wID;
-  HMENU hSubMenu;
-  HBITMAP hbmpChecked;
-  HBITMAP hbmpUnchecked;
-  ULONG_PTR dwItemData;
-  LPSTR dwTypeData;
-  UINT cch;
-  HBITMAP hbmpItem;
-} MENUITEMINFOA, *PMENUITEMINFOA, *LPMENUITEMINFOA;
-typedef struct _MENUITEMINFOW
-{
-  UINT cbSize;
-  UINT fMask;
-  UINT fType;
-  UINT fState;
-  UINT wID;
-  HMENU hSubMenu;
-  HBITMAP hbmpChecked;
-  HBITMAP hbmpUnchecked;
-  ULONG_PTR dwItemData;
-  LPWSTR dwTypeData;
-  UINT cch;
-  HBITMAP hbmpItem;
-} MENUITEMINFOW, *PMENUITEMINFOW, *LPMENUITEMINFOW;
-#include "poppack.h"
-#ifdef UNICODE
-# define MENUITEMINFO MENUITEMINFOW
-# define PMENUITEMINFO PMENUITEMINFOW
-# define LPMENUITEMINFO LPMENUITEMINFOW
-#else /* not UNICODE */
-# define MENUITEMINFO MENUITEMINFOA
-# define PMENUITEMINFO PMENUITEMINFOA
-# define LPMENUITEMINFO LPMENUITEMINFOA
-#endif /* not UNICODE */
+#include "w32menu.h"
 
 /* ja:アクセラレータ */
 typedef LPVOID HACCEL;
 
+/* ja:仮想キー */
+#define VK_LBUTTON             0x01
+#define VK_RBUTTON             0x02
+#define VK_CANCEL              0x03
+#define VK_MBUTTON             0x04
+#define VK_XBUTTON1            0x05
+#define VK_XBUTTON2            0x06
+#define VK_BACK                0x08
+#define VK_TAB                 0x09
+#define VK_CLEAR               0x0c
+#define VK_RETURN              0x0d
+#define VK_SHIFT               0x10
+#define VK_CONTROL             0x11
+#define VK_MENU                0x12
+#define VK_PAUSE               0x13
+#define VK_CAPITAL             0x14
+#define VK_KANA                0x15
+#define VK_HANGEUL             0x15
+#define VK_HANGUL              0x15
+#define VK_JUNJA               0x17
+#define VK_FINAL               0x18
+#define VK_HANJA               0x19
+#define VK_KANJI               0x19
+#define VK_ESCAPE              0x1b
+#define VK_CONVERT             0x1c
+#define VK_NONCONVERT          0x1d
+#define VK_ACCEPT              0x1e
+#define VK_MODECHANGE          0x1f
+#define VK_SPACE               0x20
+#define VK_PRIOR               0x21
+#define VK_NEXT                0x22
+#define VK_END                 0x23
+#define VK_HOME                0x24
+#define VK_LEFT                0x25
+#define VK_UP                  0x26
+#define VK_RIGHT               0x27
+#define VK_DOWN                0x28
+#define VK_SELECT              0x29
+#define VK_PRINT               0x2a
+#define VK_EXECUTE             0x2b
+#define VK_SNAPSHOT            0x2c
+#define VK_INSERT              0x2d
+#define VK_DELETE              0x2e
+#define VK_HELP                0x2f
+#define VK_0                   0x30
+#define VK_1                   0x31
+#define VK_2                   0x32
+#define VK_3                   0x33
+#define VK_4                   0x34
+#define VK_5                   0x35
+#define VK_6                   0x36
+#define VK_7                   0x37
+#define VK_8                   0x38
+#define VK_9                   0x39
+#define VK_A                   0x41
+#define VK_B                   0x42
+#define VK_C                   0x43
+#define VK_D                   0x44
+#define VK_E                   0x45
+#define VK_F                   0x46
+#define VK_G                   0x47
+#define VK_H                   0x48
+#define VK_I                   0x49
+#define VK_J                   0x4a
+#define VK_K                   0x4b
+#define VK_L                   0x4c
+#define VK_M                   0x4d
+#define VK_N                   0x4e
+#define VK_O                   0x4f
+#define VK_P                   0x50
+#define VK_Q                   0x51
+#define VK_R                   0x52
+#define VK_S                   0x53
+#define VK_T                   0x54
+#define VK_U                   0x55
+#define VK_V                   0x56
+#define VK_W                   0x57
+#define VK_X                   0x58
+#define VK_Y                   0x59
+#define VK_Z                   0x5a
+#define VK_LWIN                0x5b
+#define VK_RWIN                0x5c
+#define VK_APPS                0x5d
+#define VK_SLEEP               0x5f
+#define VK_NUMPAD0             0x60
+#define VK_NUMPAD1             0x61
+#define VK_NUMPAD2             0x62
+#define VK_NUMPAD3             0x63
+#define VK_NUMPAD4             0x64
+#define VK_NUMPAD5             0x65
+#define VK_NUMPAD6             0x66
+#define VK_NUMPAD7             0x67
+#define VK_NUMPAD8             0x68
+#define VK_NUMPAD9             0x69
+#define VK_MULTIPLY            0x6a
+#define VK_ADD                 0x6b
+#define VK_SEPARATOR           0x6c
+#define VK_SUBTRACT            0x6d
+#define VK_DECIMAL             0x6e
+#define VK_DIVIDE              0x6f
+#define VK_F1                  0x70
+#define VK_F2                  0x71
+#define VK_F3                  0x72
+#define VK_F4                  0x73
+#define VK_F5                  0x74
+#define VK_F6                  0x75
+#define VK_F7                  0x76
+#define VK_F8                  0x77
+#define VK_F9                  0x78
+#define VK_F10                 0x79
+#define VK_F11                 0x7a
+#define VK_F12                 0x7b
+#define VK_F13                 0x7c
+#define VK_F14                 0x7d
+#define VK_F15                 0x7e
+#define VK_F16                 0x7f
+#define VK_F17                 0x80
+#define VK_F18                 0x81
+#define VK_F19                 0x82
+#define VK_F20                 0x83
+#define VK_F21                 0x84
+#define VK_F22                 0x85
+#define VK_F23                 0x86
+#define VK_F24                 0x87
+#define VK_NUMLOCK             0x90
+#define VK_SCROLL              0x91
+#define VK_OEM_NEC_EQUAL       0x92
+#define VK_OEM_FJ_JISHO        0x92
+#define VK_OEM_FJ_MASSHOU      0x93
+#define VK_OEM_FJ_TOUROKU      0x94
+#define VK_OEM_FJ_LOYA         0x95
+#define VK_OEM_FJ_ROYA         0x96
+#define VK_LSHIFT              0xa0
+#define VK_RSHIFT              0xa1
+#define VK_LCONTROL            0xa2
+#define VK_RCONTROL            0xa3
+#define VK_LMENU               0xa4
+#define VK_RMENU               0xa5
+#define VK_BROWSER_BACK        0xa6
+#define VK_BROWSER_FORWARD     0xa7
+#define VK_BROWSER_REFRESH     0xa8
+#define VK_BROWSER_STOP        0xa9
+#define VK_BROWSER_SEARCH      0xaa
+#define VK_BROWSER_FAVORITES   0xab
+#define VK_BROWSER_HOME        0xac
+#define VK_VOLUME_MUTE         0xad
+#define VK_VOLUME_DOWN         0xae
+#define VK_VOLUME_UP           0xaf
+#define VK_MEDIA_NEXT_TRACK    0xb0
+#define VK_MEDIA_PREV_TRACK    0xb1
+#define VK_MEDIA_STOP          0xb2
+#define VK_MEDIA_PLAY_PAUSE    0xb3
+#define VK_LAUNCH_MAIL         0xb4
+#define VK_LAUNCH_MEDIA_SELECT 0xb5
+#define VK_LAUNCH_APP1         0xb6
+#define VK_LAUNCH_APP2         0xb7
+#define VK_OEM_1               0xba
+#define VK_OEM_PLUS            0xbb
+#define VK_OEM_COMMA           0xbc
+#define VK_OEM_MINUS           0xbd
+#define VK_OEM_PERIOD          0xbe
+#define VK_OEM_2               0xbf
+#define VK_OEM_3               0xc0
+#define VK_OEM_4               0xcb
+#define VK_OEM_5               0xcc
+#define VK_OEM_6               0xcd
+#define VK_OEM_7               0xce
+#define VK_OEM_8               0xcf
+#define VK_OEM_AX              0xe1
+#define VK_OEM_102             0xe2
+#define VK_ICO_HELP            0xe3
+#define VK_ICO_00              0xe4
+#define VK_PROCESSKEY          0xe5
+#define VK_ATTN                0xf6
+#define VK_CRSEL               0xf7
+#define VK_EXSEL               0xf8
+#define VK_EREOF               0xf9
+#define VK_PLAY                0xfa
+#define VK_ZOOM                0xfb
+#define VK_NONAME              0xfc
+#define VK_PA1                 0xfd
+#define VK_OEM_CLEAR           0xfe
+
 /* ja:クリップボード */
 #define CF_TEXT        1
 #define CF_BITMAP      2
@@ -471,6 +645,7 @@ typedef struct _MSG
 #include "poppack.h"
 
 /* ja:ウインドウ */
+#include "w32wnd.h"
 #define CreateWindowA(a,b,c,d,e,f,g,h,i,j,k) CreateWindowExA(0,a,b,c,d,e,f,g,h,i,j,k)
 #define CreateWindowW(a,b,c,d,e,f,g,h,i,j,k) CreateWindowExW(0,a,b,c,d,e,f,g,h,i,j,k)
 #ifdef UNICODE
@@ -656,6 +831,7 @@ typedef struct _CREATESTRUCTW
 #endif /* not UNICODE */
 
 /* ja:ダイアログ */
+#include "w32dlg.h"
 #define CreateDialogA(a,b,c,d) CreateDialogParamA(a,b,c,d,0)
 #define CreateDialogW(a,b,c,d) CreateDialogParamW(a,b,c,d,0)
 #define DialogBoxA(a,b,c,d) DialogBoxParamA(a,b,c,d,0)
@@ -717,6 +893,7 @@ typedef struct _DLGITEMTEMPLATEEX
 } DLGITEMTEMPLATEEX, *PDLGITEMTEMPLATEEX, *LPDLGITEMTEMPLATEEX;
 typedef CONST DLGITEMTEMPLATEEX *PCDLGITEMTEMPLATEEX, *LPCDLGITEMTEMPLATEEX;
 #include "poppack.h"
+
 /* ja:メッセージボックス */
 #define MB_OK                   0x00000000
 #define MB_OKCANCEL             0x00000001
@@ -770,6 +947,8 @@ typedef CONST DLGITEMTEMPLATEEX *PCDLGITEMTEMPLATEEX, *LPCDLGITEMTEMPLATEEX;
 extern W32LdrExport user32_exports[];
 
 
+BOOL WINAPI AppendMenuA (HMENU hMenu, UINT uFlags, UINT_PTR uItem, LPCSTR lpszItem);
+BOOL WINAPI AppendMenuW (HMENU hMenu, UINT uFlags, UINT_PTR uItem, LPCWSTR lpszItem);
 HDC WINAPI BeginPaint (HWND hWnd, LPPAINTSTRUCT lpPaint);
 LRESULT WINAPI CallWindowProcA (WNDPROC lpPrevWndFunc, HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 LRESULT WINAPI CallWindowProcW (WNDPROC lpPrevWndFunc, HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
@@ -778,27 +957,43 @@ LPWSTR WINAPI CharLowerW (LPWSTR lpsz);
 LPSTR WINAPI CharUpperA (LPSTR lpsz);
 LPWSTR WINAPI CharUpperW (LPWSTR lpsz);
 BOOL WINAPI CheckDlgButton (HWND hDlg, INT nIDButton, UINT uCheck);
+DWORD WINAPI CheckMenuItem (HMENU hMenu, UINT uItem, UINT uFlags);
+BOOL WINAPI CheckMenuRadioItem (HMENU hMenu, UINT uFirst, UINT uLast, UINT uCheck, UINT uFlags);
 BOOL WINAPI CheckRadioButton (HWND hDlg, INT nIDFirstButton, INT nIDLastButton, INT nIDCheckButton);
 BOOL WINAPI ClientToScreen (HWND hWnd, LPPOINT lpPoint);
 BOOL WINAPI ClipCursor (CONST LPRECT lpRect);
 BOOL WINAPI CloseClipboard (VOID);
+BOOL WINAPI CloseWindow (HWND hWnd);
+HICON WINAPI CopyIcon (HICON hIcon);
+HANDLE WINAPI CopyImage (HANDLE hImage, UINT uType, INT cxDesired, INT cyDesired, UINT fuFlags);
 BOOL WINAPI CopyRect (LPRECT lprcDst, CONST LPRECT lprcSrc);
 HWND WINAPI CreateDialogIndirectParamA (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 HWND WINAPI CreateDialogIndirectParamW (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 HWND WINAPI CreateDialogParamA (HINSTANCE hInstance, LPCSTR lpTemplateName, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 HWND WINAPI CreateDialogParamW (HINSTANCE hInstance, LPCWSTR lpTemplateName, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
+HMENU WINAPI CreateMenu (VOID);
+HMENU WINAPI CreatePopupMenu (VOID);
 HWND WINAPI CreateWindowExA (DWORD dwExStyle, LPCSTR lpClassName, LPCSTR lpWindowName, DWORD dwStyle, INT x, INT y, INT nWidth, INT nHeight, HWND hWndParent, HMENU hMenu, HINSTANCE hInstance, LPVOID lpParam);
 HWND WINAPI CreateWindowExW (DWORD dwExStyle, LPCWSTR lpClassName, LPCWSTR lpWindowName, DWORD dwStyle, INT x, INT y, INT nWidth, INT nHeight, HWND hWndParent, HMENU hMenu, HINSTANCE hInstance, LPVOID lpParam);
 LRESULT WINAPI DefWindowProcA (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 LRESULT WINAPI DefWindowProcW (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
+BOOL WINAPI DeleteMenu (HMENU hMenu, UINT uItem, UINT uFlags);
+BOOL WINAPI DestroyCursor (HCURSOR hCursor);
+BOOL WINAPI DestroyIcon (HICON hIcon);
+BOOL WINAPI DestroyMenu (HMENU hMenu);
 BOOL WINAPI DestroyWindow (HWND hWnd);
 INT WINAPI DialogBoxIndirectParamA (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 INT WINAPI DialogBoxIndirectParamW (HINSTANCE hInstance, LPCDLGTEMPLATE lpDialogTemplate, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 INT WINAPI DialogBoxParamA (HINSTANCE hInstance, LPCSTR lpTemplateName, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
 INT WINAPI DialogBoxParamW (HINSTANCE hInstance, LPCWSTR lpTemplateName, HWND hWndParent, DLGPROC lpDialogFunc, LPARAM dwInitParam);
+LONG WINAPI DispatchMessageA (LPMSG lpMsg);
+LONG WINAPI DispatchMessageW (LPMSG lpMsg);
+BOOL WINAPI DrawMenuBar (HWND hWnd);
 BOOL WINAPI EmptyClipboard (VOID);
+BOOL EnableMenuItem (HMENU hMenu, UINT uItem, UINT uFlags);
 BOOL WINAPI EnableWindow (HWND hWnd, BOOL bEnable);
 BOOL WINAPI EndDialog (HWND hDlg, INT nResult);
+BOOL WINAPI EndMenu (VOID);
 BOOL WINAPI EndPaint (HWND hWnd, LPPAINTSTRUCT lpPaint);
 BOOL WINAPI EnumThreadWindows (DWORD dwThreadId, WNDENUMPROC lpEnumFunc, LPARAM lParam);
 BOOL WINAPI EnumWindows (WNDENUMPROC lpEnumFunc, LPARAM lParam);
@@ -806,6 +1001,7 @@ BOOL WINAPI EqualRect (CONST LPRECT lprc1, CONST LPRECT lprc2);
 INT WINAPI GetClassNameA (HWND hWnd, LPSTR lpClassName, INT nMaxCount);
 INT WINAPI GetClassNameW (HWND hWnd, LPWSTR lpClassName, INT nMaxCount);
 BOOL WINAPI GetClientRect (HWND hWnd, LPRECT lpRect);
+HCURSOR WINAPI GetCursor (VOID);
 BOOL WINAPI GetCursorPos (LPPOINT lpPoint);
 HDC WINAPI GetDC (HWND hWnd);
 HWND WINAPI GetDesktopWindow (VOID);
@@ -814,9 +1010,23 @@ HWND WINAPI GetDlgItem (HWND hDlg, INT nIDDlgItem);
 UINT WINAPI GetDlgItemInt (HWND hDlg, INT nIDDlgItem, BOOL *lpTranslated, BOOL bSigned);
 HWND WINAPI GetFocus (VOID);
 INT WINAPI GetKeyboardType (INT nTypeFlag);
+HMENU WINAPI GetMenu (HWND hWnd);
+LONG WINAPI GetMenuCheckMarkDimensions (VOID);
+UINT WINAPI GetMenuDefaultItem (HMENU hMenu, UINT uByPos, UINT gmdiFlags);
+INT WINAPI GetMenuItemCount (HMENU hMenu);
+UINT WINAPI GetMenuItemID (HMENU hMenu, INT nPos);
+BOOL WINAPI GetMenuItemInfoA (HMENU hMenu, UINT uItem, BOOL fByPosition, LPMENUITEMINFOA lpmii);
+BOOL WINAPI GetMenuItemInfoW (HMENU hMenu, UINT uItem, BOOL fByPosition, LPMENUITEMINFOW lpmii);
+BOOL WINAPI GetMenuItemRect (HWND hWnd, HMENU hMenu, UINT uItem, LPRECT lprcItem);
+UINT WINAPI GetMenuState (HMENU hMenu, UINT uItem, UINT uFlags);
+INT WINAPI GetMenuStringA (HMENU hMenu, UINT uItem, LPSTR lpszString, INT cchMax, UINT uFlags);
+INT WINAPI GetMenuStringW (HMENU hMenu, UINT uItem, LPWSTR lpszString, INT cchMax, UINT uFlags);
+BOOL WINAPI WINAPI GetMessageA (LPMSG lpMsg, HWND hWnd, UINT wMsgFilterMin, UINT wMsgFilterMax);
+BOOL WINAPI GetMessageW (LPMSG lpMsg, HWND hWnd, UINT wMsgFilterMin, UINT wMsgFilterMax);
 HWND WINAPI GetParent (HWND hWnd);
 INT WINAPI GetScrollPos (HWND hWnd, INT nBar);
 BOOL WINAPI GetScrollRange (HWND hWnd, INT nBar, LPINT lpMinPos, LPINT lpMaxPos);
+HMENU WINAPI GetSubMenu (HMENU hMenu, INT nPos);
 DWORD WINAPI GetSysColor (int nIndex);
 HMENU WINAPI GetSystemMenu (HWND hWnd, BOOL bRevert);
 INT WINAPI GetSystemMetrics (INT nIndex);
@@ -828,27 +1038,54 @@ INT WINAPI GetWindowTextA (HWND hWnd, LPSTR lpString, INT nMaxCount);
 INT WINAPI GetWindowTextLengthA (HWND hWnd);
 INT WINAPI GetWindowTextLengthW (HWND hWnd);
 INT WINAPI GetWindowTextW (HWND hWnd, LPWSTR lpString, INT nMaxCount);
+BOOL WINAPI HiliteMenuItem (HWND hWnd, HMENU hMenu, UINT uItem, UINT uFlags);
 BOOL WINAPI InflateRect (LPRECT lprc, INT dx, INT dy);
+BOOL WINAPI InsertMenuA (HMENU hMenu, UINT uItem, UINT uFlags, UINT_PTR uNewItem, LPCSTR lpszNewItem);
+BOOL WINAPI InsertMenuItemA (HMENU hMenu, UINT uItem, BOOL fByPosition, LPMENUITEMINFOA lpmii);
+BOOL WINAPI InsertMenuItemW (HMENU hMenu, UINT uItem, BOOL fByPosition, LPMENUITEMINFOW lpmii);
+BOOL WINAPI InsertMenuW (HMENU hMenu, UINT uItem, UINT uFlags, UINT_PTR uNewItem, LPCWSTR lpszNewItem);
 BOOL WINAPI IntersectRect (LPRECT lprcDst, CONST LPRECT lprcSrc1, CONST LPRECT lprcSrc2);
 BOOL WINAPI InvalidateRect (HWND hWnd, CONST RECT *lpRect, BOOL bErase);
+BOOL WINAPI IsChild (HWND hWndParent, HWND hWndChild);
 UINT WINAPI IsDlgButtonChecked (HWND hDlg, INT nIDButton);
+BOOL WINAPI IsMenu (HMENU hMenu);
 BOOL WINAPI IsRectEmpty (CONST LPRECT lprc);
 BOOL WINAPI IsWindowEnabled (HWND hWnd);
 BOOL WINAPI IsWindowUnicode (HWND hWnd);
 BOOL WINAPI KillTimer (HWND hWnd, UINT uIDEvent);
+HACCEL WINAPI LoadAcceleratorsA (HINSTANCE hInstance, LPCSTR lpTableName);
+HACCEL WINAPI LoadAcceleratorsW (HINSTANCE hInstance, LPCWSTR lpTableName);
 HBITMAP WINAPI LoadBitmapA (HINSTANCE hInstance, LPCSTR lpBitmapName);
 HBITMAP WINAPI LoadBitmapW (HINSTANCE hInstance, LPCWSTR lpBitmapName);
+HCURSOR WINAPI LoadCursorA (HINSTANCE hInstance, LPCSTR lpCursorName);
+HCURSOR WINAPI LoadCursorW (HINSTANCE hInstance, LPCWSTR lpCursorName);
+HICON WINAPI LoadIconA (HINSTANCE hInstance, LPCSTR lpIconName);
+HICON WINAPI LoadIconW (HINSTANCE hInstance, LPCWSTR lpIconName);
+HANDLE WINAPI LoadImageA (HINSTANCE hInstance, LPCSTR lpszName, UINT uType, INT cxDesired, INT cyDesired, UINT fuLoad);
+HANDLE WINAPI LoadImageW (HINSTANCE hInstance, LPCWSTR lpszName, UINT uType, INT cxDesired, INT cyDesired, UINT fuLoad);
+HMENU WINAPI LoadMenuA (HINSTANCE hInstance, LPCSTR lpMenuName);
+HMENU WINAPI LoadMenuIndirectA (LPCMENUTEMPLATE lpMenuTemplate);
+HMENU WINAPI LoadMenuIndirectW (LPCMENUTEMPLATE lpMenuTemplate);
+HMENU WINAPI LoadMenuW (HINSTANCE hInstance, LPCWSTR lpMenuName);
 INT WINAPI LoadStringA (HINSTANCE hInstance, UINT uID, LPSTR lpBuffer, INT nBufferMax);
 INT WINAPI LoadStringW (HINSTANCE hInstance, UINT uID, LPWSTR lpBuffer, INT nBufferMax);
 INT WINAPI MapWindowPoints (HWND hWndFrom, HWND hWndTo, LPPOINT lpPoints, UINT cPoints);
+UINT WINAPI MenuItemFromPoint (HWND hWnd, HMENU hMenu, POINT ptScreen);
 BOOL WINAPI MessageBeep (UINT uType);
 INT WINAPI MessageBoxA (HWND hWnd, LPCSTR lpText, LPCSTR lpCaption, UINT uType);
 INT WINAPI MessageBoxExA (HWND hWnd, LPCSTR lpText, LPCSTR lpCaption, UINT uType, WORD wLanguageId);
 INT WINAPI MessageBoxExW (HWND hWnd, LPCWSTR lpText, LPCWSTR lpCaption, UINT uType, WORD wLanguageId);
 INT WINAPI MessageBoxW (HWND hWnd, LPCWSTR lpText, LPCWSTR lpCaption, UINT uType);
+BOOL WINAPI ModifyMenuA (HMENU hMenu, UINT uItem, UINT uFlags, UINT_PTR uNewItem, LPCSTR lpszNewItem);
+BOOL WINAPI ModifyMenuW (HMENU hMenu, UINT uItem, UINT uFlags, UINT_PTR uNewItem, LPCWSTR lpszNewItem);
 BOOL WINAPI MoveWindow (HWND hWnd, INT x, INT y, INT nWidth, INT nHeight, BOOL bRepaint);
 BOOL WINAPI OffsetRect (LPRECT lprc, INT dx, INT dy);
 BOOL WINAPI OpenClipboard (HWND hWndNewOwner);
+BOOL WINAPI PeekMessageA (LPMSG lpMsg, HWND hWnd, UINT wMsgFilterMin, UINT wMsgFilterMax, UINT wRemoveMsg);
+BOOL WINAPI PeekMessageW (LPMSG lpMsg, HWND hWnd, UINT wMsgFilterMin, UINT wMsgFilterMax, UINT wRemoveMsg);
+BOOL WINAPI PostMessageA (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
+BOOL WINAPI PostMessageW (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
+VOID WINAPI PostQuitMessage (INT nExitCode);
 BOOL WINAPI PtInRect (CONST LPRECT lprc, POINT pt);
 ATOM WINAPI RegisterClassA (CONST LPWNDCLASSA lpWndClass);
 ATOM WINAPI RegisterClassExA (CONST LPWNDCLASSEXA lpWndClassEx);
@@ -856,6 +1093,7 @@ ATOM WINAPI RegisterClassExW (CONST LPWNDCLASSEXW lpWndClassEx);
 ATOM WINAPI RegisterClassW (CONST LPWNDCLASSW lpWndClass);
 BOOL WINAPI ReleaseCapture (VOID);
 INT WINAPI ReleaseDC (HWND hWnd, HDC hDC);
+BOOL WINAPI RemoveMenu (HMENU hMenu, UINT uItem, UINT uFlags);
 BOOL WINAPI ScreenToClient (HWND hWnd, LPPOINT lpPoint);
 LONG WINAPI SendDlgItemMessageA (HWND hDlg, INT nIDDlgItem, UINT Msg, WPARAM wParam, LPARAM lParam);
 LONG WINAPI SendDlgItemMessageW (HWND hDlg, INT nIDDlgItem, UINT Msg, WPARAM wParam, LPARAM lParam);
@@ -863,12 +1101,19 @@ LRESULT WINAPI SendMessageA (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 LRESULT WINAPI SendMessageW (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 HWND WINAPI SetCapture (HWND hWnd);
 HANDLE WINAPI SetClipboardData (UINT uFormat, HANDLE hMem);
+HCURSOR WINAPI SetCursor (HCURSOR hCursor);
+BOOL WINAPI SetCursorPos (INT x, INT y);
 BOOL WINAPI SetDlgItemInt (HWND hDlg, INT nIDDlgItem, UINT uValue, BOOL bSigned);
 BOOL WINAPI SetDlgItemTextA (HWND hDlg, INT nIDDlgItem, LPCSTR lpString);
 BOOL WINAPI SetDlgItemTextW (HWND hDlg, INT nIDDlgItem, LPCWSTR lpString);
 HWND WINAPI SetFocus (HWND hWnd);
 BOOL WINAPI SetForegroundWindow (HWND hWnd);
-BOOL WINAPI SetRect (LPRECT lprc, int xLeft, int yTop, int xRight, int yBottom);
+BOOL WINAPI SetMenu (HWND hWnd, HMENU hMenu);
+BOOL WINAPI SetMenuDefaultItem (HMENU hMenu, UINT uItem, UINT uByPos);
+BOOL WINAPI SetMenuItemBitmaps (HMENU hMenu, UINT uItem, UINT uFlags, HBITMAP hbmUnchecked, HBITMAP hbmChecked);
+BOOL WINAPI SetMenuItemInfoA (HMENU hMenu, UINT uItem, BOOL fByPosition, LPMENUITEMINFOA lpmii);
+BOOL WINAPI SetMenuItemInfoW (HMENU hMenu, UINT uItem, BOOL fByPosition, LPMENUITEMINFOW lpmii);
+BOOL WINAPI SetRect (LPRECT lprc, INT xLeft, INT yTop, INT xRight, INT yBottom);
 BOOL WINAPI SetRectEmpty (LPRECT lprc);
 INT WINAPI SetScrollPos (HWND hWnd, INT nBar, INT nPos, BOOL bRedraw);
 BOOL WINAPI SetScrollRange (HWND hWnd, INT nBar, INT nMinPos, INT nMaxPos, BOOL bRedraw);
@@ -882,6 +1127,11 @@ BOOL WINAPI ShowWindow (HWND hWnd, INT nCmdShow);
 BOOL WINAPI SubtractRect (LPRECT lprcDst, CONST LPRECT lprcSrc1, CONST LPRECT lprcSrc2);
 BOOL WINAPI SystemParametersInfoA (UINT uiAction, UINT uiParam, PVOID pvParam, UINT fWinIni);
 BOOL WINAPI SystemParametersInfoW (UINT uiAction, UINT uiParam, PVOID pvParam, UINT fWinIni);
+BOOL WINAPI TrackPopupMenu (HMENU hMenu, UINT uFlags, INT x, INT y, INT nReserved, HWND hWnd, LPCRECT lprcRect);
+BOOL WINAPI TrackPopupMenuEx (HMENU hMenu, UINT uFlags, INT x, INT y, HWND hWnd, LPTPMPARAMS lptpm);
+INT WINAPI TranslateAcceleratorA (HWND hWnd, HACCEL hAccel, LPMSG lpMsg);
+INT WINAPI TranslateAcceleratorW (HWND hWnd, HACCEL hAccel, LPMSG lpMsg);
+BOOL WINAPI TranslateMessage (CONST MSG *lpMsg);
 BOOL WINAPI UnionRect (LPRECT lprcDst, CONST LPRECT lprcSrc1, CONST LPRECT lprcSrc2);
 BOOL WINAPI UnregisterClassA (LPCSTR lpClassName, HINSTANCE hInstance);
 BOOL WINAPI UnregisterClassW (LPCWSTR lpClassName, HINSTANCE hInstance);
@@ -896,6 +1146,7 @@ INT WINAPI wvsprintfW (LPSTR lpOutput, LPCSTR lpFormat, va_list arglist);
 
 
 #ifdef UNICODE
+# define AppendMenu AppendMenuW
 # define CallWindowProc CallWindowProcW
 # define CharLower CharLowerW
 # define CharUpper CharUpperW
@@ -905,27 +1156,45 @@ INT WINAPI wvsprintfW (LPSTR lpOutput, LPCSTR lpFormat, va_list arglist);
 # define DefWindowProc DefWindowProcW
 # define DialogBoxIndirectParam DialogBoxIndirectParamW
 # define DialogBoxParam DialogBoxParamW
+# define DispatchMessage DispatchMessageW
 # define GetClassName GetClassNameW
+# define GetMenuItemInfo GetMenuItemInfoW
+# define GetMenuString GetMenuStringW
+# define GetMessage GetMessageW
 # define GetWindowLong GetWindowLongW
 # define GetWindowText GetWindowTextW
 # define GetWindowTextLength GetWindowTextLengthW
+# define InsertMenu InsertMenuW
+# define InsertMenuItem InsertMenuItemW
+# define LoadAccelerators LoadAcceleratorsW
 # define LoadBitmap LoadBitmapW
+# define LoadCursor LoadCursorW
+# define LoadIcon LoadIconW
+# define LoadImage LoadImageW
+# define LoadMenu LoadMenuW
+# define LoadMenuIndirect LoadMenuIndirectW
 # define LoadString LoadStringW
 # define MessageBox MessageBoxW
 # define MessageBoxEx MessageBoxExW
+# define ModifyMenu ModifyMenuW
+# define PeekMessage PeekMessageW
+# define PostMessage PostMessageW
 # define RegisterClass RegisterClassW
 # define RegisterClassEx RegisterClassExW
 # define SendDlgItemMessage SendDlgItemMessageW
 # define SendMessage SendMessageW
 # define SetDlgItemText SetDlgItemTextW
+# define SetMenuItemInfo SetMenuItemInfoW
 # define SetWindowLong SetWindowLongW
 # define SetWindowText SetWindowTextW
 # define SystemParametersInfo SystemParametersInfoW
+# define TranslateAccelerator TranslateAcceleratorW
 # define UnregisterClass UnregisterClassW
 # define WinHelp WinHelpW
 # define wsprintf wsprintfW
 # define wvsprintf wvsprintfW
 #else /* not UNICODE*/
+# define AppendMenu AppendMenuA
 # define CallWindowProc CallWindowProcA
 # define CharLower CharLowerA
 # define CharUpper CharUpperA
@@ -935,22 +1204,39 @@ INT WINAPI wvsprintfW (LPSTR lpOutput, LPCSTR lpFormat, va_list arglist);
 # define DefWindowProc DefWindowProcA
 # define DialogBoxIndirectParam DialogBoxIndirectParamA
 # define DialogBoxParam DialogBoxParamA
+# define DispatchMessage DispatchMessageA
 # define GetClassName GetClassNameA
+# define GetMenuItemInfo GetMenuItemInfoA
+# define GetMenuString GetMenuStringA
+# define GetMessage GetMessageA
 # define GetWindowLong GetWindowLongA
 # define GetWindowText GetWindowTextA
 # define GetWindowTextLength GetWindowTextLengthA
+# define InsertMenu InsertMenuA
+# define InsertMenuItem InsertMenuItemA
+# define LoadAccelerators LoadAcceleratorsA
 # define LoadBitmap LoadBitmapA
+# define LoadCursor LoadCursorA
+# define LoadIcon LoadIconA
+# define LoadImage LoadImageA
+# define LoadMenu LoadMenuA
+# define LoadMenuIndirect LoadMenuIndirectA
 # define LoadString LoadStringA
 # define MessageBox MessageBoxA
 # define MessageBoxEx MessageBoxExA
+# define ModifyMenu ModifyMenuA
+# define PeekMessage PeekMessageA
+# define PostMessage PostMessageA
 # define RegisterClass RegisterClassA
 # define RegisterClassEx RegisterClassExA
 # define SendDlgItemMessage SendDlgItemMessageA
 # define SendMessage SendMessageA
 # define SetDlgItemText SetDlgItemTextA
+# define SetMenuItemInfo SetMenuItemInfoA
 # define SetWindowLong SetWindowLongA
 # define SetWindowText SetWindowTextA
 # define SystemParametersInfo SystemParametersInfoA
+# define TranslateAccelerator TranslateAcceleratorA
 # define UnregisterClass UnregisterClassA
 # define WinHelp WinHelpA
 # define wsprintf wsprintfA
