@@ -921,6 +921,8 @@ w32ldr_filename_from_mb (const gchar *mb)
   g_free (str);
   utf8str = g_utf16_to_utf8 (utf16str, -1, NULL, NULL, NULL);
   g_free (utf16str);
+  if (!utf8str)
+    return NULL;
   if (g_ascii_isalpha (utf8str[i]) && utf8str[i + 1] == ':')
     g_memmove (utf8str, utf8str + 2,
                                     (g_strlen (utf8str) - 1) * sizeof (gchar));
@@ -1128,7 +1130,7 @@ w32ldr_tchar_to_wc (gchar *str)
       gchar *utf8str;
 
       utf8str = g_locale_to_utf8 (str, -1, NULL, NULL, NULL);
-      wc = g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL);
+      wc = utf8str ? g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL) : NULL;
       g_free (utf8str);
     }
   /* ja:文字符号化方式不明 */
@@ -1481,7 +1483,7 @@ w32ldr_atom_get_name_wc (const guint16 atom)
   gunichar2 *wc;
 
   utf8str = w32ldr_atom_get_name (atom);
-  wc = g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL);
+  wc = utf8str ? g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL) : NULL;
   g_free (utf8str);
   return wc;
 }
