@@ -21,6 +21,9 @@
 
 
 #include "windef.h"
+#include "w32brush.h"
+#include "w32font.h"
+#include "w32pen.h"
 
 
 #ifdef __cplusplus
@@ -51,7 +54,16 @@ typedef struct _W32LdrExport
   gchar *name;
   gpointer func;
 } W32LdrExport;
-
+typedef struct _W32LdrDC
+{
+  GtkWidget *widget;
+  gboolean transparent;
+  GdkColor fgcolor, bgcolor;
+  GdkPixbuf *pixbuf;
+  W32LdrBrush *brush;
+  W32LdrFont *font;
+  W32LdrPen *pen;
+} W32LdrDC;
 
 
 /******************************************************************************
