@@ -24,8 +24,9 @@
 
 #define TVIEW_ITEM     0
 #define TVIEW_EXPANDED 1
-#define TVIEW_TEXT     2
-#define TVIEW_LPARAM   3
+#define TVIEW_EDITABLE 2
+#define TVIEW_TEXT     3
+#define TVIEW_LPARAM   4
 
 
 static gint
@@ -136,13 +137,13 @@ w32tview_DefWindowProc (HWND   hWnd,
               gtk_tree_iter_free (sibling);
             if (tvis->item.mask & TVIF_STATE)
               {
-                if (tvis->item.stateMask & LVIS_SELECTED)
+                if (tvis->item.stateMask & TVIS_SELECTED)
                   {
                     GtkTreeSelection *select;
 
                     select = gtk_tree_view_get_selection
                                                     (GTK_TREE_VIEW (tview));
-                    if (tvis->item.state & LVIS_SELECTED)
+                    if (tvis->item.state & TVIS_SELECTED)
                       gtk_tree_selection_select_iter (select, &iter);
                     else
                       gtk_tree_selection_unselect_iter (select, &iter);
@@ -157,10 +158,11 @@ w32tview_DefWindowProc (HWND   hWnd,
                                                 && tvis->item.cChildren > 0))
               gtk_tree_model_ref_node (GTK_TREE_MODEL (store), &iter);
             gtk_tree_store_set (store, &iter,
-                                        TVIEW_ITEM, item_count,
-                                        TVIEW_EXPANDED, expanded,
-                                        TVIEW_TEXT, utf8str,
-                                        TVIEW_LPARAM, tvis->item.lParam, -1);
+                                TVIEW_ITEM, item_count,
+                                TVIEW_EXPANDED, expanded,
+                                TVIEW_EDITABLE, wd->dwStyle & TVS_EDITLABELS,
+                                TVIEW_TEXT, utf8str,
+                                TVIEW_LPARAM, tvis->item.lParam, -1);
             g_free (utf8str);
             return item_count++;
           }
@@ -218,13 +220,13 @@ w32tview_DefWindowProc (HWND   hWnd,
               gtk_tree_iter_free (sibling);
             if (tvis->item.mask & TVIF_STATE)
               {
-                if (tvis->item.stateMask & LVIS_SELECTED)
+                if (tvis->item.stateMask & TVIS_SELECTED)
                   {
                     GtkTreeSelection *select;
 
                     select = gtk_tree_view_get_selection
                                                     (GTK_TREE_VIEW (tview));
-                    if (tvis->item.state & LVIS_SELECTED)
+                    if (tvis->item.state & TVIS_SELECTED)
                       gtk_tree_selection_select_iter (select, &iter);
                     else
                       gtk_tree_selection_unselect_iter (select, &iter);
@@ -240,10 +242,11 @@ w32tview_DefWindowProc (HWND   hWnd,
                                                 && tvis->item.cChildren > 0))
               gtk_tree_model_ref_node (GTK_TREE_MODEL (store), &iter);
             gtk_tree_store_set (store, &iter,
-                                        TVIEW_ITEM, item_count,
-                                        TVIEW_EXPANDED, expanded,
-                                        TVIEW_TEXT, utf8str,
-                                        TVIEW_LPARAM, tvis->item.lParam, -1);
+                                TVIEW_ITEM, item_count,
+                                TVIEW_EXPANDED, expanded,
+                                TVIEW_EDITABLE, wd->dwStyle & TVS_EDITLABELS,
+                                TVIEW_TEXT, utf8str,
+                                TVIEW_LPARAM, tvis->item.lParam, -1);
             g_free (utf8str);
             return item_count++;
           }
@@ -261,10 +264,10 @@ w32tview_DefWindowProc (HWND   hWnd,
             }
           else
             {
-              GtkTreeIter  *iter;
+              GtkTreeIter *iter;
 
               iter = w32tview_get_iter_from_item (GTK_TREE_MODEL (store),
-                                                                    lParam);
+                                                                        lParam);
               if (iter)
                 {
                   gtk_tree_store_remove (store, iter);
@@ -276,7 +279,7 @@ w32tview_DefWindowProc (HWND   hWnd,
         return FALSE;
       case TVM_EXPAND:
         {
-          GtkTreeIter  *iter;
+          GtkTreeIter *iter;
           GtkTreeStore *store;
 
           store = GTK_TREE_STORE (gtk_tree_view_get_model
@@ -528,7 +531,7 @@ w32tview_DefWindowProc (HWND   hWnd,
                     tvi->state = (gtk_tree_selection_iter_is_selected
                                             (select, iter) ? TVIS_SELECTED : 0)
                                         | (expanded ? TVIS_EXPANDEDONCE : 0);
-                    tvi->stateMask = LVIS_SELECTED | TVIS_EXPANDEDONCE;
+                    tvi->stateMask = TVIS_SELECTED | TVIS_EXPANDEDONCE;
                     path = gtk_tree_model_get_path (model, iter);
                     if (path)
                       {
@@ -611,7 +614,7 @@ w32tview_DefWindowProc (HWND   hWnd,
                     tvi->state = (gtk_tree_selection_iter_is_selected
                                             (select, iter) ? TVIS_SELECTED : 0)
                                         | (expanded ? TVIS_EXPANDEDONCE : 0);
-                    tvi->stateMask = LVIS_SELECTED | TVIS_EXPANDEDONCE;
+                    tvi->stateMask = TVIS_SELECTED | TVIS_EXPANDEDONCE;
                     path = gtk_tree_model_get_path (model, iter);
                     if (path)
                       {
@@ -686,13 +689,13 @@ w32tview_DefWindowProc (HWND   hWnd,
                                                 TVIEW_EXPANDED, &expanded, -1);
                 if (tvi->mask & TVIF_STATE)
                   {
-                    if (tvi->stateMask & LVIS_SELECTED)
+                    if (tvi->stateMask & TVIS_SELECTED)
                       {
                         GtkTreeSelection *select;
 
                         select = gtk_tree_view_get_selection
                                                     (GTK_TREE_VIEW (tview));
-                        if (tvi->state & LVIS_SELECTED)
+                        if (tvi->state & TVIS_SELECTED)
                           gtk_tree_selection_select_iter (select, iter);
                         else
                           gtk_tree_selection_unselect_iter (select, iter);
@@ -779,13 +782,13 @@ w32tview_DefWindowProc (HWND   hWnd,
                                                 TVIEW_EXPANDED, &expanded, -1);
                 if (tvi->mask & TVIF_STATE)
                   {
-                    if (tvi->stateMask & LVIS_SELECTED)
+                    if (tvi->stateMask & TVIS_SELECTED)
                       {
                         GtkTreeSelection *select;
 
                         select = gtk_tree_view_get_selection
                                                     (GTK_TREE_VIEW (tview));
-                        if (tvi->state & LVIS_SELECTED)
+                        if (tvi->state & TVIS_SELECTED)
                           gtk_tree_selection_select_iter (select, iter);
                         else
                           gtk_tree_selection_unselect_iter (select, iter);
@@ -1063,7 +1066,7 @@ w32tview_DefWindowProc (HWND   hWnd,
 static void
 w32tview_row_deleted (GtkTreeModel *model,
                       GtkTreePath  *path,
-                      GtkWidget    *widget)
+                      GtkWidget    *tview)
 {
   GtkTreeIter iter;
 
@@ -1071,16 +1074,18 @@ w32tview_row_deleted (GtkTreeModel *model,
     {
       gint param;
       guint item;
+      GtkWidget *parent;
       W32LdrWindowData *wd;
 
-      wd = g_object_get_data (G_OBJECT (widget), "user_data");
+      parent = gtk_widget_get_parent (tview);
+      wd = g_object_get_data (G_OBJECT (parent), "user_data");
       gtk_tree_model_get (model, &iter,
                                 TVIEW_ITEM, &item, TVIEW_LPARAM, &param, -1);
       if (wd->widechar)
         {
           NM_TREEVIEWW nmt;
 
-          nmt.hdr.hwndFrom = widget;
+          nmt.hdr.hwndFrom = parent;
           nmt.hdr.idFrom = wd->wID;
           nmt.hdr.code = TVN_DELETEITEMW;
           nmt.action = 0;
@@ -1113,7 +1118,7 @@ w32tview_row_deleted (GtkTreeModel *model,
         {
           NM_TREEVIEWA nmt;
 
-          nmt.hdr.hwndFrom = widget;
+          nmt.hdr.hwndFrom = parent;
           nmt.hdr.idFrom = wd->wID;
           nmt.hdr.code = TVN_DELETEITEMA;
           nmt.action = 0;
@@ -1156,10 +1161,12 @@ w32tview_changed (GtkTreeSelection *select,
   guint item = 0;
   GtkTreeIter iter;
   GtkTreeModel *model;
-  GtkWidget *tview;
+  GtkWidget *tview, *parent;
   W32LdrWindowData *wd;
 
   tview = GTK_WIDGET (gtk_tree_selection_get_tree_view (select));
+  parent = gtk_widget_get_parent (tview);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
   if (gtk_tree_selection_get_selected (select, &model, &iter))
     {
       GtkTreePath *path;
@@ -1170,12 +1177,11 @@ w32tview_changed (GtkTreeSelection *select,
       expand = gtk_tree_view_row_expanded (GTK_TREE_VIEW (tview), path);
       gtk_tree_path_free (path);
     }
-  wd = g_object_get_data (G_OBJECT (tview), "user_data");
   if (wd->widechar)
     {
       NM_TREEVIEWW nmt;
 
-      nmt.hdr.hwndFrom = tview;
+      nmt.hdr.hwndFrom = parent;
       nmt.hdr.idFrom = wd->wID;
       nmt.hdr.code = TVN_SELCHANGINGW;
       nmt.action = 0;
@@ -1214,7 +1220,7 @@ w32tview_changed (GtkTreeSelection *select,
     {
       NM_TREEVIEWA nmt;
 
-      nmt.hdr.hwndFrom = tview;
+      nmt.hdr.hwndFrom = parent;
       nmt.hdr.idFrom = wd->wID;
       nmt.hdr.code = TVN_SELCHANGINGA;
       nmt.action = 0;
@@ -1264,9 +1270,11 @@ w32tview_test_collapse_row (GtkTreeView *tview,
   guint item;
   GtkTreeModel *model;
   GtkTreeSelection *select;
+  GtkWidget *parent;
   W32LdrWindowData *wd;
 
-  wd = g_object_get_data (G_OBJECT (tview), "user_data");
+  parent = gtk_widget_get_parent (GTK_WIDGET (tview));
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
   select = gtk_tree_view_get_selection (tview);
   model = gtk_tree_view_get_model (tview);
   gtk_tree_model_get (model, iter,
@@ -1275,7 +1283,7 @@ w32tview_test_collapse_row (GtkTreeView *tview,
     {
       NM_TREEVIEWW nmt;
 
-      nmt.hdr.hwndFrom = GTK_WIDGET (tview);
+      nmt.hdr.hwndFrom = parent;
       nmt.hdr.idFrom = wd->wID;
       nmt.hdr.code = TVN_ITEMEXPANDINGW;
       nmt.action = TVE_COLLAPSE;
@@ -1317,7 +1325,7 @@ w32tview_test_collapse_row (GtkTreeView *tview,
     {
       NM_TREEVIEWA nmt;
 
-      nmt.hdr.hwndFrom = GTK_WIDGET (tview);
+      nmt.hdr.hwndFrom = parent;
       nmt.hdr.idFrom = wd->wID;
       nmt.hdr.code = TVN_ITEMEXPANDINGA;
       nmt.action = TVE_COLLAPSE;
@@ -1351,11 +1359,11 @@ w32tview_test_collapse_row (GtkTreeView *tview,
         {
           nmt.hdr.code = TVN_ITEMEXPANDEDA;
           nmt.itemNew.state &= ~TVIS_EXPANDED;
-          SendMessageW (wd->hWndParent, WM_NOTIFY,
+          SendMessageA (wd->hWndParent, WM_NOTIFY,
                                             wd->wID, GPOINTER_TO_INT (&nmt));
         }
     }
-  return collapse;
+  return !collapse;
 }
 
 
@@ -1371,9 +1379,11 @@ w32tview_test_expand_row (GtkTreeView *tview,
   guint item;
   GtkTreeSelection *select;
   GtkTreeStore *store;
+  GtkWidget *parent;
   W32LdrWindowData *wd;
 
-  wd = g_object_get_data (G_OBJECT (tview), "user_data");
+  parent = gtk_widget_get_parent (GTK_WIDGET (tview));
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
   select = gtk_tree_view_get_selection (tview);
   store = GTK_TREE_STORE (gtk_tree_view_get_model (tview));
   gtk_tree_model_get (GTK_TREE_MODEL (store), iter, TVIEW_ITEM, &item,
@@ -1387,7 +1397,7 @@ w32tview_test_expand_row (GtkTreeView *tview,
         {
           NM_TREEVIEWW nmt;
 
-          nmt.hdr.hwndFrom = GTK_WIDGET (tview);
+          nmt.hdr.hwndFrom = parent;
           nmt.hdr.idFrom = wd->wID;
           nmt.hdr.code = TVN_ITEMEXPANDINGW;
           nmt.action = TVE_EXPAND;
@@ -1430,7 +1440,7 @@ w32tview_test_expand_row (GtkTreeView *tview,
         {
           NM_TREEVIEWA nmt;
 
-          nmt.hdr.hwndFrom = GTK_WIDGET (tview);
+          nmt.hdr.hwndFrom = parent;
           nmt.hdr.idFrom = wd->wID;
           nmt.hdr.code = TVN_ITEMEXPANDINGA;
           nmt.action = TVE_EXPAND;
@@ -1465,12 +1475,12 @@ w32tview_test_expand_row (GtkTreeView *tview,
               gtk_tree_store_set (store, iter, TVIEW_EXPANDED, TRUE, -1);
               nmt.hdr.code = TVN_ITEMEXPANDEDA;
               nmt.itemNew.state |= TVIS_EXPANDED | TVIS_EXPANDEDONCE;
-              SendMessageW (wd->hWndParent, WM_NOTIFY,
+              SendMessageA (wd->hWndParent, WM_NOTIFY,
                                             wd->wID, GPOINTER_TO_INT (&nmt));
             }
         }
     }
-  return expanded;
+  return !expanded;
 }
 
 
@@ -1480,6 +1490,7 @@ w32tview_button_press_event (GtkWidget      *widget,
                              GdkEventButton *event,
                              gpointer        user_data)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NMHDR nmh;
 
@@ -1503,8 +1514,9 @@ w32tview_button_press_event (GtkWidget      *widget,
         break;
       default: return FALSE;
     }
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nmh.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nmh.hwndFrom = parent;
   nmh.idFrom = wd->wID;
   if (wd->widechar)
     SendMessageW (wd->hWndParent, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
@@ -1520,11 +1532,13 @@ w32tview_focus_in (GtkWidget     *widget,
                    GdkEventFocus *event,
                    gpointer       user_data)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NMHDR nmh;
 
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nmh.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nmh.hwndFrom = parent;
   nmh.idFrom = wd->wID;
   nmh.code = NM_SETFOCUS;
   if (wd->widechar)
@@ -1541,11 +1555,13 @@ w32tview_focus_out (GtkWidget     *widget,
                     GdkEventFocus *event,
                     gpointer       user_data)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NMHDR nmh;
 
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nmh.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nmh.hwndFrom = parent;
   nmh.idFrom = wd->wID;
   nmh.code = NM_KILLFOCUS;
   if (wd->widechar)
@@ -1564,11 +1580,13 @@ w32tview_key_press_event (GtkWidget   *widget,
 {
   if (event->keyval == GDK_Return)
     {
+      GtkWidget *parent;
       W32LdrWindowData *wd;
       NMHDR nmh;
 
-      wd = g_object_get_data (G_OBJECT (widget), "user_data");
-      nmh.hwndFrom = widget;
+      parent = gtk_widget_get_parent (widget);
+      wd = g_object_get_data (G_OBJECT (parent), "user_data");
+      nmh.hwndFrom = parent;
       nmh.idFrom = wd->wID;
       nmh.code = NM_RETURN;
       if (wd->widechar)
@@ -1600,8 +1618,8 @@ w32ldr_control_create_tview (const gchar    *windowname,
   GtkWidget *tview, *scroll;
   W32LdrWindowData *wd;
 
-  /* ja:リストビュー */
-  store = gtk_tree_store_new (4, G_TYPE_UINT, G_TYPE_BOOLEAN,
+  /* ja:ツリービュー */
+  store = gtk_tree_store_new (5, G_TYPE_UINT, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
                                                     G_TYPE_STRING, G_TYPE_INT);
   tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tview), FALSE);
@@ -1619,8 +1637,7 @@ w32ldr_control_create_tview (const gchar    *windowname,
 #endif /* GTK_CHECK_VERSION(2,10,0) */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (NULL, renderer,
-                                    "text", TVIEW_TEXT,
-                                    "editable", style & TVS_EDITLABELS, NULL);
+                        "text", TVIEW_TEXT, "editable", TVIEW_EDITABLE, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tview));
   gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
@@ -1642,7 +1659,8 @@ w32ldr_control_create_tview (const gchar    *windowname,
                             G_CALLBACK (w32tview_key_press_event), NULL);
   gtk_widget_add_events (tview, GDK_BUTTON_PRESS_MASK | GDK_FOCUS_CHANGE_MASK
                                                         | GDK_KEY_PRESS_MASK);
-  g_object_unref (store);
+  g_object_unref (G_OBJECT (store));
+  gtk_widget_show (tview);
   /* ja:スクロールウインドウ */
   scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
