@@ -171,8 +171,9 @@ HDRVR WINAPI OpenDriver (LPCWSTR lpDriverName, LPCWSTR lpSectionName, LONG lPara
   HKEY hKey;
 
   hdrvr = g_malloc (sizeof (struct _HDRVR));
-  utf8str = g_utf16_to_utf8 (lpDriverName, -1, NULL, NULL, NULL);
-  file = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
+  utf8str = lpDriverName ? g_utf16_to_utf8 (lpDriverName, -1, NULL, NULL, NULL)
+                         : NULL;
+  file = utf8str ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
   g_free (utf8str);
   hdrvr->module = w32ldr_module_load_library (file, TRUE);
   g_free (file);
