@@ -176,6 +176,7 @@ typedef struct _W32LdrWinsock
   gulong handler;
 } W32LdrWinsock;
 
+
 /* AcceptEx ordinal = 1141, argument = 32 temporary */
 static DWORD WINAPI AcceptEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
 {
@@ -321,7 +322,7 @@ typedef struct _W32LdrHostent
 
 
 static gpointer
-hostent_gethostbyname (W32LdrHostent *w32hostent)
+winsock_WSAAsyncGetHostByName (W32LdrHostent *w32hostent)
 {
   gint aliases = 0, addr_list = 0;
   gsize buflen;
@@ -391,19 +392,19 @@ hostent_gethostbyname (W32LdrHostent *w32hostent)
                     }
                   ht->h_addr_list[i] = NULL;
                 }
-              SendMessageA (w32hostent->hWnd, w32hostent->wMsg,
+              SendMessage (w32hostent->hWnd, w32hostent->wMsg,
                             GPOINTER_TO_INT (w32hostent), MAKELPARAM (0, 0));
             }
           else
             {
-              SendMessageA (w32hostent->hWnd, w32hostent->wMsg,
+              SendMessage (w32hostent->hWnd, w32hostent->wMsg,
                                             GPOINTER_TO_INT (w32hostent),
                                                 MAKELPARAM (0, WSAENOBUFS));
             }
         }
       else
         {
-          SendMessageA (w32hostent->hWnd, w32hostent->wMsg,
+          SendMessage (w32hostent->hWnd, w32hostent->wMsg,
                                             GPOINTER_TO_INT (w32hostent),
                                             MAKELPARAM (0, WSAHOST_NOT_FOUND));
         }
@@ -416,8 +417,8 @@ hostent_gethostbyname (W32LdrHostent *w32hostent)
 
 
 static void
-w32winsock_destroy (GtkWidget     *widget,
-                    W32LdrWinsock *w32winsock)
+winsock_destroy (GtkWidget     *widget,
+                 W32LdrWinsock *w32winsock)
 {
   if (w32winsock->handler != 0)
     {
@@ -445,13 +446,14 @@ HANDLE WINAPI WSAAsyncGetHostByName (HWND hWnd, UINT wMsg, LPCSTR name, LPSTR bu
   w32winsock = &w32hostent->w32winsock;
   w32winsock->widget = hWnd;
   w32winsock->handler = g_signal_connect (G_OBJECT (hWnd), "destroy",
-                                G_CALLBACK (w32winsock_destroy), w32winsock);
+                                    G_CALLBACK (winsock_destroy), w32winsock);
 #ifdef USE_THREAD
-  g_thread_create ((GThreadFunc)hostent_gethostbyname, w32hostent, TRUE, NULL);
+  g_thread_create ((GThreadFunc)winsock_WSAAsyncGetHostByName, w32hostent,
+                                                                TRUE, NULL);
 #else /* not USE_THREAD */
-  hostent_gethostbyname (w32hostent);
+  winsock_WSAAsyncGetHostByName (w32hostent);
 #endif /* not USE_THREAD */
-  return (HANDLE)w32hostent;
+  return w32hostent;
 }
 
 
@@ -494,11 +496,11 @@ typedef struct _W32LdrSelect
 } W32LdrSelect;
 
 
-GList *glist_socket = NULL;
+static GList *glist_socket = NULL;
 
 
 static gboolean
-select_polling (gpointer data)
+winsock_select_polling (gpointer data)
 {
   GList *glist;
   int nfds = -1;
@@ -533,13 +535,13 @@ select_polling (gpointer data)
 
         w32select = glist->data;
         if (FD_ISSET (w32select->sockfd, &rfds))
-          SendMessageA (w32select->hWnd, w32select->wMsg,
+          SendMessage (w32select->hWnd, w32select->wMsg,
                                 w32select->sockfd, MAKELPARAM (FD_READ, 0));
         if (FD_ISSET (w32select->sockfd, &wfds))
-          SendMessageA (w32select->hWnd, w32select->wMsg,
+          SendMessage (w32select->hWnd, w32select->wMsg,
                                 w32select->sockfd, MAKELPARAM (FD_WRITE, 0));
         if (FD_ISSET (w32select->sockfd, &efds))
-          SendMessageA (w32select->hWnd, w32select->wMsg,
+          SendMessage (w32select->hWnd, w32select->wMsg,
                                 w32select->sockfd, MAKELPARAM (FD_OOB, 0));
         w32select->lMask &= ~(FD_READ | FD_WRITE | FD_OOB);
       }
@@ -548,8 +550,8 @@ select_polling (gpointer data)
 
 
 static void
-select_destroy (GtkWidget    *widget,
-                W32LdrSelect *w32select)
+winsock_select_destroy (GtkWidget    *widget,
+                        W32LdrSelect *w32select)
 {
   WSAAsyncSelect (w32select->sockfd, w32select->hWnd, 0, 0);
 }
@@ -571,10 +573,10 @@ INT WINAPI WSAAsyncSelect (SOCKET sockfd, HWND hWnd, UINT wMsg, LONG lEvent)
       w32select->lMask = lEvent;
       w32select->w32winsock.widget = hWnd;
       w32select->w32winsock.handler = g_signal_connect (G_OBJECT (hWnd),
-                            "destroy", G_CALLBACK (select_destroy), w32select);
+                    "destroy", G_CALLBACK (winsock_select_destroy), w32select);
       glist_socket = g_list_append (glist_socket, w32select);
       if (timer == 0)
-        timer = g_timeout_add (500, select_polling, NULL);
+        timer = g_timeout_add (500, winsock_select_polling, NULL);
     }
   else
     {
@@ -613,7 +615,7 @@ INT WINAPI WSACancelAsyncRequest (HANDLE hAsyncTaskHandle)
     {
       W32LdrWinsock *w32winsock;
 
-      w32winsock = (W32LdrWinsock *)hAsyncTaskHandle;
+      w32winsock = hAsyncTaskHandle;
       if (w32winsock->handler != 0)
         {
           g_signal_handler_disconnect (G_OBJECT (w32winsock->widget),
@@ -743,7 +745,7 @@ int WINAPI closesocket (int sockfd)
                         && (w32select->lEvent & w32select->lMask & FD_CLOSE))
         {
           w32select->lMask &= ~FD_CLOSE;
-          SendMessageA (w32select->hWnd, w32select->wMsg,
+          SendMessage (w32select->hWnd, w32select->wMsg,
                             w32select->sockfd, MAKELPARAM (FD_CLOSE, result));
         }
     }
@@ -768,7 +770,7 @@ int WINAPI winsock_connect (int sockfd, const struct sockaddr *serv_addr, sockle
                         && (w32select->lEvent & w32select->lMask & FD_CONNECT))
         {
           w32select->lMask &= ~FD_CONNECT;
-          SendMessageA (w32select->hWnd, w32select->wMsg,
+          SendMessage (w32select->hWnd, w32select->wMsg,
                         w32select->sockfd, MAKELPARAM (FD_CONNECT, result));
         }
     }
@@ -920,7 +922,7 @@ int WINAPI winsock_listen (int sockfd, int backlog)
                         && (w32select->lEvent & w32select->lMask & FD_ACCEPT))
           {
             w32select->lMask &= ~FD_ACCEPT;
-            SendMessageA (w32select->hWnd, w32select->wMsg,
+            SendMessage (w32select->hWnd, w32select->wMsg,
                                 w32select->sockfd, MAKELPARAM (FD_ACCEPT, 0));
           }
       }
